@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *
  *  (C) 2001 by Argonne National Laboratory.
@@ -32,8 +32,8 @@
 /*@
    MPI_Type_free_keyval - Frees an attribute key for datatypes
 
-Input Parameter:
-. keyval - Frees the integer key value (integer) 
+Input Parameters:
+. type_keyval - Frees the integer key value (integer)
 
 .N ThreadSafe
 
