@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *
  *  (C) 2001 by Argonne National Laboratory.
@@ -351,7 +351,7 @@ int MPIR_Barrier_impl(MPID_Comm *comm_ptr, int *errflag)
 MPI_Barrier - Blocks until all processes in the communicator have
 reached this routine.  
 
-Input Parameter:
+Input Parameters:
 . comm - communicator (handle) 
 
 Notes:
