@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -28,14 +28,16 @@
 #define FCNAME MPIU_QUOTE(FUNCNAME)
 void MPIR_Get_count_impl(const MPI_Status *status, MPI_Datatype datatype, int *count)
 {
-    int size;
-    /* Check for correct number of bytes */
+    MPI_Count size;
+
     MPID_Datatype_get_size_macro(datatype, size);
+    MPIU_Assert(size >= 0 && status->count >= 0);
     if (size != 0) {
-	if ((status->count % size) != 0)
+        /* MPI-3 says return MPI_UNDEFINED if too large for an int */
+	if ((status->count % size) != 0 || ((status->count / size) > INT_MAX))
 	    (*count) = MPI_UNDEFINED;
 	else
-	    (*count) = status->count / size;
+	    (*count) = (int)(status->count / size);
     } else {
 	if (status->count > 0) {
 	    /* --BEGIN ERROR HANDLING-- */
@@ -70,7 +72,7 @@ Input Parameters:
 + status - return status of receive operation (Status) 
 - datatype - datatype of each receive buffer element (handle) 
 
-Output Parameter:
+Output Parameters:
 . count - number of received elements (integer) 
 Notes:
 If the size of the datatype is zero, this routine will return a count of
@@ -84,7 +86,7 @@ size of 'datatype' (so that 'count' would not be integral), a 'count' of
 .N MPI_SUCCESS
 .N MPI_ERR_TYPE
 @*/
-int MPI_Get_count( MPICH2_CONST MPI_Status *status, MPI_Datatype datatype, int *count )
+int MPI_Get_count( const MPI_Status *status, MPI_Datatype datatype, int *count )
 {
     int mpi_errno = MPI_SUCCESS;
     MPID_MPI_STATE_DECL(MPID_STATE_MPI_GET_COUNT);
