@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *
  *  (C) 2001 by Argonne National Laboratory.
@@ -58,7 +58,7 @@ int MPIR_Type_commit_impl(MPI_Datatype *datatype)
 /*@
     MPI_Type_commit - Commits the datatype
 
-Input Parameter:
+Input Parameters:
 . datatype - datatype (handle) 
 
 .N ThreadSafe
@@ -77,6 +77,7 @@ int MPI_Type_commit(MPI_Datatype *datatype)
 
     MPIR_ERRTEST_INITIALIZED_ORDIE();
     
+    MPIU_THREAD_CS_ENTER(ALLFUNC,);
     MPID_MPI_FUNC_ENTER(MPID_STATE_MPI_TYPE_COMMIT);
     
     /* Validate parameters, especially handles needing to be converted */
@@ -116,6 +117,7 @@ int MPI_Type_commit(MPI_Datatype *datatype)
     
   fn_exit:
     MPID_MPI_FUNC_EXIT(MPID_STATE_MPI_TYPE_COMMIT);
+    MPIU_THREAD_CS_EXIT(ALLFUNC,);
     return mpi_errno;
 
   fn_fail:
