@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *
  *  (C) 2001 by Argonne National Laboratory.
@@ -325,7 +325,7 @@ PMPI_LOCAL int MPIR_Type_cyclic(const int *array_of_gsizes,
 /*@
    MPI_Type_create_darray - Create a datatype representing a distributed array
 
-   Input Parameters:
+Input Parameters:
 + size - size of process group (positive integer)
 . rank - rank in process group (nonnegative integer)
 . ndims - number of array dimensions as well as process grid dimensions (positive integer)
@@ -336,7 +336,7 @@ PMPI_LOCAL int MPIR_Type_cyclic(const int *array_of_gsizes,
 . order - array storage order flag (state)
 - oldtype - old datatype (handle)
 
-    Output Parameter:
+Output Parameters:
 . newtype - new datatype (handle)
 
 .N ThreadSafe
@@ -351,10 +351,10 @@ PMPI_LOCAL int MPIR_Type_cyclic(const int *array_of_gsizes,
 int MPI_Type_create_darray(int size,
 			   int rank,
 			   int ndims,
-			   MPICH2_CONST int array_of_gsizes[],
-			   MPICH2_CONST int array_of_distribs[],
-			   MPICH2_CONST int array_of_dargs[],
-			   MPICH2_CONST int array_of_psizes[],
+			   const int array_of_gsizes[],
+			   const int array_of_distribs[],
+			   const int array_of_dargs[],
+			   const int array_of_psizes[],
 			   int order,
 			   MPI_Datatype oldtype,
 			   MPI_Datatype *newtype)
@@ -403,9 +403,11 @@ int MPI_Type_create_darray(int size,
         MPID_BEGIN_ERROR_CHECKS;
         {
 	    /* Check parameters */
-	    MPIR_ERRTEST_ARGNEG(rank, "rank", mpi_errno);
-	    MPIR_ERRTEST_ARGNONPOS(size, "size", mpi_errno);
-	    MPIR_ERRTEST_ARGNONPOS(ndims, "ndims", mpi_errno);
+	    MPIR_ERRTEST_ARGNONPOS(size, "size", mpi_errno, MPI_ERR_ARG);
+            /* use MPI_ERR_RANK class for PE-MPI compatibility */
+            MPIU_ERR_CHKANDJUMP3((rank < 0 || rank >= size), mpi_errno, MPI_ERR_RANK,
+                                 "**argrange", "**argrange %s %d %d", "rank", rank, (size-1));
+	    MPIR_ERRTEST_ARGNONPOS(ndims, "ndims", mpi_errno, MPI_ERR_DIMS);
 
 	    MPIR_ERRTEST_ARGNULL(array_of_gsizes, "array_of_gsizes", mpi_errno);
 	    MPIR_ERRTEST_ARGNULL(array_of_distribs, "array_of_distribs", mpi_errno);
@@ -423,9 +425,10 @@ int MPI_Type_create_darray(int size,
                 goto fn_fail;
 	    }
 
+            tmp_size = 1;
 	    for (i=0; mpi_errno == MPI_SUCCESS && i < ndims; i++) {
-		MPIR_ERRTEST_ARGNONPOS(array_of_gsizes[i], "gsize", mpi_errno);
-		MPIR_ERRTEST_ARGNONPOS(array_of_psizes[i], "psize", mpi_errno);
+		MPIR_ERRTEST_ARGNONPOS(array_of_gsizes[i], "gsize", mpi_errno, MPI_ERR_ARG);
+		MPIR_ERRTEST_ARGNONPOS(array_of_psizes[i], "psize", mpi_errno, MPI_ERR_ARG);
 
 		if ((array_of_distribs[i] != MPI_DISTRIBUTE_NONE) &&
 		    (array_of_distribs[i] != MPI_DISTRIBUTE_BLOCK) &&
@@ -468,8 +471,13 @@ int MPI_Type_create_darray(int size,
 						     i, array_of_psizes[i]);
                     goto fn_fail;
 		}
+
+                tmp_size *= array_of_psizes[i];
 	    }
 
+            MPIU_ERR_CHKANDJUMP1((tmp_size != size), mpi_errno, MPI_ERR_ARG,
+                                 "**arg", "**arg %s", "array_of_psizes");
+
 	    /* TODO: GET THIS CHECK IN ALSO */
 
 	    /* check if MPI_Aint is large enough for size of global array.
