@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *
  *  (C) 2001 by Argonne National Laboratory.
@@ -29,17 +29,11 @@
 #define FCNAME MPIU_QUOTE(FUNCNAME)
 void MPIR_Type_get_extent_impl(MPI_Datatype datatype, MPI_Aint *lb, MPI_Aint *extent)
 {
-    MPID_Datatype *datatype_ptr = NULL;
+    MPI_Count lb_x, extent_x;
 
-    MPID_Datatype_get_ptr(datatype, datatype_ptr);
-
-    if (HANDLE_GET_KIND(datatype) == HANDLE_KIND_BUILTIN) {
-	*lb     = 0;
-	*extent = MPID_Datatype_get_basic_size(datatype);
-    } else {
-	*lb     = datatype_ptr->lb;
-	*extent = datatype_ptr->extent; /* derived, should be same as ub - lb */
-    }
+    MPIR_Type_get_extent_x_impl(datatype, &lb_x, &extent_x);
+    *lb = (lb_x > MPIR_AINT_MAX) ? MPI_UNDEFINED : (MPI_Aint)lb_x;
+    *extent = (extent_x > MPIR_AINT_MAX) ? MPI_UNDEFINED : (MPI_Aint)extent_x;
 }
 
 #endif
@@ -51,10 +45,10 @@ void MPIR_Type_get_extent_impl(MPI_Datatype datatype, MPI_Aint *lb, MPI_Aint *ex
 /*@
    MPI_Type_get_extent - Get the lower bound and extent for a Datatype
 
-   Input Parameter:
+Input Parameters:
 . datatype - datatype to get information on (handle)
 
-   Output Parameters:
+Output Parameters:
 + lb - lower bound of datatype (address integer)
 - extent - extent of datatype (address integer)
 
