@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *
  *  (C) 2001 by Argonne National Laboratory.
@@ -32,10 +32,10 @@
 /*@
   MPI_Errhandler_get - Gets the error handler for a communicator
 
-Input Parameter:
+Input Parameters:
 . comm - communicator to get the error handler from (handle) 
 
-Output Parameter:
+Output Parameters:
 . errhandler - MPI error handler currently associated with communicator
 (handle) 
 
