@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *
  *  (C) 2001 by Argonne National Laboratory.
@@ -28,7 +28,7 @@
 #define FUNCNAME MPIR_Group_incl_impl
 #undef FCNAME
 #define FCNAME MPIU_QUOTE(FUNCNAME)
-int MPIR_Group_incl_impl(MPID_Group *group_ptr, int n, const int *ranks, MPID_Group **new_group_ptr)
+int MPIR_Group_incl_impl(MPID_Group *group_ptr, int n, const int ranks[], MPID_Group **new_group_ptr)
 {
     int mpi_errno = MPI_SUCCESS;
     int i;
@@ -83,7 +83,7 @@ Input Parameters:
 - ranks - ranks of processes in 'group' to appear in 'newgroup' (array of 
 integers) 
 
-Output Parameter:
+Output Parameters:
 . newgroup - new group derived from above, in the order defined by 'ranks' 
 (handle) 
 
@@ -100,7 +100,7 @@ Output Parameter:
 
 .seealso: MPI_Group_free
 @*/
-int MPI_Group_incl(MPI_Group group, int n, MPICH2_CONST int *ranks, MPI_Group *newgroup)
+int MPI_Group_incl(MPI_Group group, int n, const int ranks[], MPI_Group *newgroup)
 {
     int mpi_errno = MPI_SUCCESS;
     MPID_Group *group_ptr = NULL, *new_group_ptr = NULL;
