@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *
  *  (C) 2001 by Argonne National Laboratory.
@@ -127,7 +127,7 @@ Input Parameters:
 form (first rank, last rank, stride), indicating the ranks in
 'group'  of processes to be excluded from the output group 'newgroup' .  
 
-Output Parameter:
+Output Parameters:
 . newgroup - new group derived from above, preserving the 
 order in 'group'  (handle) 
 
