@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -29,7 +29,7 @@
 /*@
    MPI_Initialized - Indicates whether 'MPI_Init' has been called.
 
-Output Argument:
+Output Parameters:
 . flag - Flag is true if 'MPI_Init' or 'MPI_Init_thread' has been called and 
          false otherwise.  
 
