@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -30,7 +30,7 @@
    MPI_Query_thread - Return the level of thread support provided by the MPI 
     library
 
-   Output Parameter:
+Output Parameters:
 .  provided - Level of thread support provided.  This is the same value
    that was returned in the 'provided' argument in 'MPI_Init_thread'.
 
