@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *
  *  (C) 2001 by Argonne National Laboratory.
@@ -31,7 +31,7 @@
 /*@
     MPI_Start - Initiates a communication with a persistent request handle
 
-Input Parameter:
+Input Parameters:
 . request - communication request (handle) 
 
 .N ThreadSafe
