@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *
  *  (C) 2001 by Argonne National Laboratory.
@@ -40,12 +40,12 @@ Input Parameters:
 - array_of_requests - array of requests (array of handles) 
 
 Output Parameters:
-+ index - index of handle for operation that completed (integer).  In the
++ indx - index of handle for operation that completed (integer).  In the
 range '0' to 'count-1'.  In Fortran, the range is '1' to 'count'.
 - status - status object (Status).  May be 'MPI_STATUS_IGNORE'.
 
 Notes:
-If all of the requests are 'MPI_REQUEST_NULL', then 'index' is returned as 
+If all of the requests are 'MPI_REQUEST_NULL', then 'indx' is returned as
 'MPI_UNDEFINED', and 'status' is returned as an empty status.
 
 While it is possible to list a request handle more than once in the
@@ -63,7 +63,7 @@ program to unexecpectedly terminate or produce incorrect results.
 .N MPI_ERR_REQUEST
 .N MPI_ERR_ARG
 @*/
-int MPI_Waitany(int count, MPI_Request array_of_requests[], int *index, 
+int MPI_Waitany(int count, MPI_Request array_of_requests[], int *indx,
 		MPI_Status *status)
 {
     static const char FCNAME[] = "MPI_Waitany";
@@ -96,7 +96,7 @@ int MPI_Waitany(int count, MPI_Request array_of_requests[], int *index,
 		/* NOTE: MPI_STATUS_IGNORE != NULL */
 		MPIR_ERRTEST_ARGNULL(status, "status", mpi_errno);
 	    }
-	    MPIR_ERRTEST_ARGNULL(index, "index", mpi_errno);
+	    MPIR_ERRTEST_ARGNULL(indx, "indx", mpi_errno);
 	}
         MPID_END_ERROR_CHECKS;
     }
@@ -167,7 +167,7 @@ int MPI_Waitany(int count, MPI_Request array_of_requests[], int *index,
 						  &active_flag);
 		if (active_flag)
 		{
-		    *index = i;
+		    *indx = i;
 		    goto break_l1;
 		}
 		else
@@ -177,7 +177,7 @@ int MPI_Waitany(int count, MPI_Request array_of_requests[], int *index,
 
 		    if (n_inactive == count)
 		    {
-			*index = MPI_UNDEFINED;
+			*indx = MPI_UNDEFINED;
 			/* status is set to empty by MPIR_Request_complete */
 			goto break_l1;
 		    }
@@ -189,7 +189,7 @@ int MPI_Waitany(int count, MPI_Request array_of_requests[], int *index,
         if (!found_nonnull_req)
         {
             /* all requests were NULL */
-            *index = MPI_UNDEFINED;
+            *indx = MPI_UNDEFINED;
             if (status != NULL)    /* could be null if count=0 */
                 MPIR_Status_set_empty(status);
             goto break_l1;
@@ -223,7 +223,7 @@ int MPI_Waitany(int count, MPI_Request array_of_requests[], int *index,
 				     FCNAME, __LINE__, MPI_ERR_OTHER,
 				     "**mpi_waitany", 
 				     "**mpi_waitany %d %p %p %p", 
-				     count, array_of_requests, index, status);
+				     count, array_of_requests, indx, status);
 #endif
     mpi_errno = MPIR_Err_return_comm(NULL, FCNAME, mpi_errno);
     goto fn_exit;
