@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *
  *  (C) 2001 by Argonne National Laboratory.
@@ -6,51 +6,77 @@
  */
 
 #include "mpiimpl.h"
-#include "rma.h"
 
-/* -- Begin Profiling Symbol Block for routine MPIX_Get_accumulate */
+/* -- Begin Profiling Symbol Block for routine MPI_Get_accumulate */
 #if defined(HAVE_PRAGMA_WEAK)
-#pragma weak MPIX_Get_accumulate = PMPIX_Get_accumulate
+#pragma weak MPI_Get_accumulate = PMPI_Get_accumulate
 #elif defined(HAVE_PRAGMA_HP_SEC_DEF)
-#pragma _HP_SECONDARY_DEF PMPIX_Get_accumulate  MPIX_Get_accumulate
+#pragma _HP_SECONDARY_DEF PMPI_Get_accumulate  MPI_Get_accumulate
 #elif defined(HAVE_PRAGMA_CRI_DUP)
-#pragma _CRI duplicate MPIX_Get_accumulate as PMPIX_Get_accumulate
+#pragma _CRI duplicate MPI_Get_accumulate as PMPI_Get_accumulate
 #endif
 /* -- End Profiling Symbol Block */
 
 /* Define MPICH_MPI_FROM_PMPI if weak symbols are not supported to build
    the MPI routines */
 #ifndef MPICH_MPI_FROM_PMPI
-#undef MPIX_Get_accumulate
-#define MPIX_Get_accumulate PMPIX_Get_accumulate
+#undef MPI_Get_accumulate
+#define MPI_Get_accumulate PMPI_Get_accumulate
 
 #endif
 
 #undef FUNCNAME
-#define FUNCNAME MPIX_Get_accumulate
+#define FUNCNAME MPI_Get_accumulate
 
 /*@
-   MPIX_Get_accumulate - Accumulate data into the target process using remote 
-   memory access 
+MPI_Get_accumulate - Perform an atomic, one-sided read-and-accumulate operation.
 
-   Input Parameters:
-+ origin_addr - initial address of buffer (choice) 
-. origin_count - number of entries in buffer (nonnegative integer) 
-. origin_datatype - datatype of each buffer entry (handle) 
+
+Accumulate origin_count elements of type origin_datatype from the origin buffer
+(origin_addr) to the buffer at offset target_disp, in the target window
+specified by target_rank and win, using the operation op and return in the
+result buffer result_addr the content of the target buffer before the
+accumulation.
+
+Input Parameters:
++ origin_addr - initial address of buffer (choice)
+. origin_count - number of entries in buffer (nonnegative integer)
+. origin_datatype - datatype of each buffer entry (handle)
 . result_addr - initial address of result buffer (choice)
 . result_count - number of entries in result buffer (non-negative integer)
 . result_datatype - datatype of each entry in result buffer (handle)
-. target_rank - rank of target (nonnegative integer) 
-. target_disp - displacement from start of window to beginning of target 
-  buffer (nonnegative integer)  
-. target_count - number of entries in target buffer (nonnegative integer) 
-. target_datatype - datatype of each entry in target buffer (handle) 
-. op - predefined reduce operation (handle) 
-- win - window object (handle) 
+. target_rank - rank of target (nonnegative integer)
+. target_disp - displacement from start of window to beginning of target
+  buffer (nonnegative integer)
+. target_count - number of entries in target buffer (nonnegative integer)
+. target_datatype - datatype of each entry in target buffer (handle)
+. op - predefined reduce operation (handle)
+- win - window object (handle)
 
-   Notes:
-The basic components of both the origin and target datatype must be the same 
-predefined datatype (e.g., all 'MPI_INT' or all 'MPI_DOUBLE_PRECISION').
+Notes:
+This operations is atomic with respect to other "accumulate" operations.
+
+The get and accumulate steps are executed atomically for each basic element in
+the datatype (see MPI 3.0 Section 11.7 for details). The predefined operation
+'MPI_REPLACE' provides fetch-and-set behavior.
+
+The origin and result buffers (origin_addr and result_addr) must be disjoint.
+Each datatype argument must be a predefined datatype or a derived datatype
+where all basic components are of the same predefined datatype. All datatype
+arguments must be constructed from the same predefined datatype. The
+operation op applies to elements of that predefined type. target_datatype must
+not specify overlapping entries, and the target buffer must fit in the target
+window or in attached memory in a dynamic window.
+
+Any of the predefined operations for 'MPI_Reduce', as well as 'MPI_NO_OP' or
+'MPI_REPLACE' can be specified as op. User-defined functions cannot be used. A
+new predefined operation, 'MPI_NO_OP', is defined. It corresponds to the
+associative function f (a, b) = a; i.e., the current value in the target memory
+is returned in the result buffer at the origin and no operation is performed on
+the target buffer. 'MPI_NO_OP' can be used only in 'MPI_Get_accumulate',
+'MPI_Rget_accumulate', and 'MPI_Fetch_and_op'. 'MPI_NO_OP' cannot be used in
+'MPI_Accumulate', 'MPI_Raccumulate', or collective reduction operations, such as
+'MPI_Reduce' and others.
 
 .N Fortran
 
@@ -61,21 +87,23 @@ predefined datatype (e.g., all 'MPI_INT' or all 'MPI_DOUBLE_PRECISION').
 .N MPI_ERR_RANK
 .N MPI_ERR_TYPE
 .N MPI_ERR_WIN
+
+.seealso: MPI_Rget_accumulate MPI_Fetch_and_op
 @*/
-int MPIX_Get_accumulate(const void *origin_addr, int origin_count,
+int MPI_Get_accumulate(const void *origin_addr, int origin_count,
         MPI_Datatype origin_datatype, void *result_addr, int result_count,
         MPI_Datatype result_datatype, int target_rank, MPI_Aint target_disp,
         int target_count, MPI_Datatype target_datatype, MPI_Op op, MPI_Win win)
 {
-    static const char FCNAME[] = "MPIX_Get_accumulate";
+    static const char FCNAME[] = "MPI_Get_accumulate";
     int mpi_errno = MPI_SUCCESS;
     MPID_Win *win_ptr = NULL;
-    MPID_MPI_STATE_DECL(MPID_STATE_MPIX_GET_ACCUMULATE);
+    MPID_MPI_STATE_DECL(MPID_STATE_MPI_GET_ACCUMULATE);
 
     MPIR_ERRTEST_INITIALIZED_ORDIE();
     
     MPIU_THREAD_CS_ENTER(ALLFUNC,);
-    MPID_MPI_RMA_FUNC_ENTER(MPID_STATE_MPIX_GET_ACCUMULATE);
+    MPID_MPI_RMA_FUNC_ENTER(MPID_STATE_MPI_GET_ACCUMULATE);
 
     /* Validate parameters, especially handles needing to be converted */
 #   ifdef HAVE_ERROR_CHECKING
@@ -102,16 +130,21 @@ int MPIX_Get_accumulate(const void *origin_addr, int origin_count,
             MPID_Win_valid_ptr( win_ptr, mpi_errno );
             if (mpi_errno) goto fn_fail;
 
-            MPIR_ERRTEST_COUNT(origin_count, mpi_errno);
-            MPIR_ERRTEST_DATATYPE(origin_datatype, "origin_datatype", mpi_errno);
+            if (op != MPI_NO_OP) {
+                MPIR_ERRTEST_COUNT(origin_count, mpi_errno);
+                MPIR_ERRTEST_DATATYPE(origin_datatype, "origin_datatype", mpi_errno);
+                MPIR_ERRTEST_ARGNULL(origin_addr, "origin_addr", mpi_errno);
+            }
             MPIR_ERRTEST_COUNT(result_count, mpi_errno);
             MPIR_ERRTEST_DATATYPE(result_datatype, "result_datatype", mpi_errno);
+            MPIR_ERRTEST_ARGNULL(result_addr, "result_addr", mpi_errno);
             MPIR_ERRTEST_COUNT(target_count, mpi_errno);
             MPIR_ERRTEST_DATATYPE(target_datatype, "target_datatype", mpi_errno);
-            if (win_ptr->create_flavor != MPIX_WIN_FLAVOR_DYNAMIC)
+            if (win_ptr->create_flavor != MPI_WIN_FLAVOR_DYNAMIC)
                 MPIR_ERRTEST_DISP(target_disp, mpi_errno);
 
-            if (HANDLE_GET_KIND(origin_datatype) != HANDLE_KIND_BUILTIN)
+            if (op != MPI_NO_OP &&
+                HANDLE_GET_KIND(origin_datatype) != HANDLE_KIND_BUILTIN)
             {
                 MPID_Datatype *datatype_ptr = NULL;
                 
@@ -146,7 +179,7 @@ int MPIX_Get_accumulate(const void *origin_addr, int origin_count,
 
             comm_ptr = win_ptr->comm_ptr;
             MPIR_ERRTEST_SEND_RANK(comm_ptr, target_rank, mpi_errno);
-            MPIR_ERRTEST_OP(op, mpi_errno);
+            MPIR_ERRTEST_OP_GACC(op, mpi_errno);
         }
         MPID_END_ERROR_CHECKS;
     }
@@ -154,8 +187,6 @@ int MPIX_Get_accumulate(const void *origin_addr, int origin_count,
 
     /* ... body of routine ...  */
     
-    if (target_rank == MPI_PROC_NULL) goto fn_exit;
-
     mpi_errno = MPIU_RMA_CALL(win_ptr,Get_accumulate(origin_addr, origin_count, 
                                          origin_datatype,
                                          result_addr, result_count,
@@ -167,7 +198,7 @@ int MPIX_Get_accumulate(const void *origin_addr, int origin_count,
     /* ... end of body of routine ... */
 
   fn_exit:
-    MPID_MPI_RMA_FUNC_EXIT(MPID_STATE_MPIX_GET_ACCUMULATE);
+    MPID_MPI_RMA_FUNC_EXIT(MPID_STATE_MPI_GET_ACCUMULATE);
     MPIU_THREAD_CS_EXIT(ALLFUNC,);
     return mpi_errno;
 
@@ -176,8 +207,8 @@ int MPIX_Get_accumulate(const void *origin_addr, int origin_count,
 #   ifdef HAVE_ERROR_CHECKING
     {
         mpi_errno = MPIR_Err_create_code(
-            mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpix_get_accumulate",
-            "**mpix_get_accumulate %p %d %D %p %d %D %d %d %d %D %O %W", origin_addr, origin_count, origin_datatype,
+            mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_get_accumulate",
+            "**mpi_get_accumulate %p %d %D %p %d %D %d %d %d %D %O %W", origin_addr, origin_count, origin_datatype,
             result_addr, result_count, result_datatype,
             target_rank, target_disp, target_count, target_datatype, op, win);
     }
