@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *   Copyright (C) 1997 University of Chicago.
  *   See COPYRIGHT notice in top-level directory.
@@ -71,4 +71,21 @@ void ADIOI_LUSTRE_ReadStrided(ADIO_File fd, void *buf, int count,
 void ADIOI_LUSTRE_Fcntl(ADIO_File fd, int flag, ADIO_Fcntl_t *fcntl_struct,
 	               int *error_code);
 void ADIOI_LUSTRE_SetInfo(ADIO_File fd, MPI_Info users_info, int *error_code);
+
+/* the lustre utilities: */
+int ADIOI_LUSTRE_Docollect(ADIO_File fd, int contig_access_count,
+			   ADIO_Offset *len_list, int nprocs);
+
+void ADIOI_LUSTRE_Get_striping_info(ADIO_File fd, int **striping_info_ptr,
+				    int mode);
+void ADIOI_LUSTRE_Calc_my_req(ADIO_File fd, ADIO_Offset *offset_list,
+			      ADIO_Offset *len_list, int contig_access_count,
+			      int *striping_info, int nprocs,
+                              int *count_my_req_procs_ptr,
+			      int **count_my_req_per_proc_ptr,
+			      ADIOI_Access **my_req_ptr,
+			      int ***buf_idx_ptr);
+
+int ADIOI_LUSTRE_Calc_aggregator(ADIO_File fd, ADIO_Offset off,
+                                 ADIO_Offset *len, int *striping_info);
 #endif /* End of AD_UNIX_INCLUDE */
