@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /* 
  *   ad_panfs.c
  *
@@ -13,6 +13,7 @@
 
 struct ADIOI_Fns_struct ADIO_PANFS_operations = {
     ADIOI_PANFS_Open, /* Open */
+    ADIOI_GEN_OpenColl,
     ADIOI_PANFS_ReadContig, /* ReadContig */
     ADIOI_PANFS_WriteContig, /* WriteContig */
     ADIOI_GEN_ReadStridedColl, /* ReadStridedColl */
@@ -39,4 +40,5 @@ struct ADIOI_Fns_struct ADIO_PANFS_operations = {
     ADIOI_GEN_Flush, /* Flush */
     ADIOI_PANFS_Resize, /* Resize */
     ADIOI_GEN_Delete, /* Delete */
+    ADIOI_GEN_Feature,
 };
