@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /* 
  *
  *   Copyright (C) 2004 University of Chicago. 
@@ -15,18 +15,6 @@
 void ADIOI_FAKE_IOComplete(ADIO_Request *request, ADIO_Status *status,
 			  int *error_code)
 {
-    if (*request == ADIO_REQUEST_NULL) {
         *error_code = MPI_SUCCESS;
-        return;
-    }
-
-#ifdef HAVE_STATUS_SET_BYTES
-    MPIR_Status_set_bytes(status, (*request)->datatype, (*request)->nbytes);
-#endif
-
-    (*request)->fd->async_count--;
-
-    ADIOI_Free_request((ADIOI_Req_node *) (*request));
-    *request = ADIO_REQUEST_NULL;
-    *error_code = MPI_SUCCESS;
+	return;
 }
