@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /* 
  *
  *   Copyright (C) 1997 University of Chicago. 
@@ -8,7 +8,7 @@
 #include "adio.h"
 #include "mpi.h"
 
-#if defined(MPICH2)
+#if defined(MPICH2) || (defined(MPICH) && (MPICH_NAME >= 3))
 /* Not quite correct, but much closer for MPI2 */
 /* TODO: still needs to handle partial datatypes and situations where the mpi
  * implementation fills status with something other than bytes (globus2 might
@@ -23,20 +23,6 @@ int MPIR_Status_set_bytes(MPI_Status *status, MPI_Datatype datatype,
         MPI_Status_set_elements(status, MPI_BYTE, nbytes);
     return MPI_SUCCESS;
 }
-#elif defined(MPICH)
-
-void MPID_Status_set_bytes(MPI_Status *status, int nbytes);
-int MPIR_Status_set_bytes(MPI_Status *status, MPI_Datatype datatype, 
-			  int nbytes);
-
-int MPIR_Status_set_bytes(MPI_Status *status, MPI_Datatype datatype, 
-			  int nbytes)
-{
-    if (status != MPI_STATUS_IGNORE)
-        MPID_Status_set_bytes(status, nbytes);
-    return MPI_SUCCESS;
-}
-
 #elif defined(MPILAM) || defined(MPISGI)
 int MPIR_Status_set_bytes(MPI_Status *status, MPI_Datatype datatype,
 		int nbytes)
