@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /* 
  *
  *   Copyright (C) 1997 University of Chicago. 
@@ -35,20 +35,17 @@ Output Parameters:
 
 .N fortran
 @*/
-int MPI_File_get_type_extent(MPI_File mpi_fh, MPI_Datatype datatype, 
-                             MPI_Aint *extent)
+int MPI_File_get_type_extent(MPI_File fh, MPI_Datatype datatype, MPI_Aint *extent)
 {
     int error_code;
-    ADIO_File fh;
+    ADIO_File adio_fh;
     static char myname[] = "MPI_FILE_GET_TYPE_EXTENT";
 
-    MPIR_Nest_incr();
-
-    fh = MPIO_File_resolve(mpi_fh);
+    adio_fh = MPIO_File_resolve(fh);
 
     /* --BEGIN ERROR HANDLING-- */
-    MPIO_CHECK_FILE_HANDLE(fh, myname, error_code);
-    MPIO_CHECK_DATATYPE(fh, datatype, myname, error_code);
+    MPIO_CHECK_FILE_HANDLE(adio_fh, myname, error_code);
+    MPIO_CHECK_DATATYPE(adio_fh, datatype, myname, error_code);
     /* --END ERROR HANDLING-- */
 
     /* FIXME: handle other file data representations */
@@ -56,6 +53,5 @@ int MPI_File_get_type_extent(MPI_File mpi_fh, MPI_Datatype datatype,
     error_code = MPI_Type_extent(datatype, extent);
 
 fn_exit:
-    MPIR_Nest_decr();
     return error_code;
 }
