@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /* 
  *
  *   Copyright (C) 1997 University of Chicago. 
@@ -32,66 +32,67 @@ Input Parameters:
 
 .N fortran
 @*/
-int MPI_File_preallocate(MPI_File mpi_fh, MPI_Offset size)
+int MPI_File_preallocate(MPI_File fh, MPI_Offset size)
 {
     ADIO_Fcntl_t *fcntl_struct;
     int error_code=0, mynod=0;
-    ADIO_File fh;
+    ADIO_File adio_fh;
     static char myname[] = "MPI_FILE_PREALLOCATE";
-    MPI_Offset tmp_sz;
+    MPI_Offset tmp_sz, max_sz, min_sz;
 #ifdef MPI_hpux
     int fl_xmpi;
 
     HPMP_IO_START(fl_xmpi, BLKMPIFILEPREALLOCATE, TRDTBLOCK,
-		  fh, MPI_DATATYPE_NULL, -1);
+		  adio_fh, MPI_DATATYPE_NULL, -1);
 #endif /* MPI_hpux */
 
     MPIU_THREAD_CS_ENTER(ALLFUNC,);
 
-    fh = MPIO_File_resolve(mpi_fh);
+    adio_fh = MPIO_File_resolve(fh);
 
     /* --BEGIN ERROR HANDLING-- */
-    MPIO_CHECK_FILE_HANDLE(fh, myname, error_code);
+    MPIO_CHECK_FILE_HANDLE(adio_fh, myname, error_code);
 
     if (size < 0) {
 	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
 					  myname, __LINE__, MPI_ERR_ARG,
 					  "**iobadsize", 0);
-	error_code = MPIO_Err_return_file(fh, error_code);
+	error_code = MPIO_Err_return_file(adio_fh, error_code);
 	goto fn_exit;
     }
 
     tmp_sz = size;
-    MPI_Bcast(&tmp_sz, 1, ADIO_OFFSET, 0, fh->comm);
+    MPI_Allreduce(&tmp_sz, &max_sz, 1, ADIO_OFFSET, MPI_MAX, adio_fh->comm);
+    MPI_Allreduce(&tmp_sz, &min_sz, 1, ADIO_OFFSET, MPI_MIN, adio_fh->comm);
 
-    if (tmp_sz != size) {
+    if (max_sz != min_sz) {
 	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
 					  myname, __LINE__, MPI_ERR_ARG,
 					  "**notsame", 0);
-	error_code = MPIO_Err_return_file(fh, error_code);
+	error_code = MPIO_Err_return_file(adio_fh, error_code);
 	goto fn_exit;
     }
     /* --END ERROR HANDLING-- */
 
     if (size == 0) goto fn_exit;
 
-    ADIOI_TEST_DEFERRED(fh, myname, &error_code);
+    ADIOI_TEST_DEFERRED(adio_fh, myname, &error_code);
 
-    MPI_Comm_rank(fh->comm, &mynod);
+    MPI_Comm_rank(adio_fh->comm, &mynod);
     if (!mynod) {
 	fcntl_struct = (ADIO_Fcntl_t *) ADIOI_Malloc(sizeof(ADIO_Fcntl_t));
 	fcntl_struct->diskspace = size;
-	ADIO_Fcntl(fh, ADIO_FCNTL_SET_DISKSPACE, fcntl_struct, &error_code);
+	ADIO_Fcntl(adio_fh, ADIO_FCNTL_SET_DISKSPACE, fcntl_struct, &error_code);
 	ADIOI_Free(fcntl_struct);
 	/* --BEGIN ERROR HANDLING-- */
 	if (error_code != MPI_SUCCESS)
-	    error_code = MPIO_Err_return_file(fh, error_code);
+	    error_code = MPIO_Err_return_file(adio_fh, error_code);
 	/* --END ERROR HANDLING-- */
     }
-    MPI_Barrier(fh->comm);
+    MPI_Barrier(adio_fh->comm);
     
 #ifdef MPI_hpux
-    HPMP_IO_END(fl_xmpi, fh, MPI_DATATYPE_NULL, -1);
+    HPMP_IO_END(fl_xmpi, adio_fh, MPI_DATATYPE_NULL, -1);
 #endif /* MPI_hpux */
 
 
