@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /* 
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -27,13 +27,13 @@
   MPI_Register_datarep - Register functions for user-defined data 
                          representations
 
-  Input Parameters:
-+ name - data representation name (string)
-. read_conv_fn - function invoked to convert from file representation to
+Input Parameters:
++ datarep - data representation name (string)
+. read_conversion_fn - function invoked to convert from file representation to
                  native representation (function)
-. write_conv_fn - function invoked to convert from native representation to
+. write_conversion_fn - function invoked to convert from native representation to
                   file representation (function)
-. extent_fn - function invoked to get the exted of a datatype as represented
+. dtype_file_extent_fn - function invoked to get the exted of a datatype as represented
                   in the file (function)
 - extra_state - pointer to extra state that is passed to each of the
                 three functions
@@ -48,14 +48,14 @@
 .N fortran
   
   @*/
-int MPI_Register_datarep(MPICH2_CONST char *name,
-			 MPI_Datarep_conversion_function *read_conv_fn,
-			 MPI_Datarep_conversion_function *write_conv_fn,
-			 MPI_Datarep_extent_function *extent_fn,
-			 void *state)
+int MPI_Register_datarep(const char *datarep,
+			 MPI_Datarep_conversion_function *read_conversion_fn,
+			 MPI_Datarep_conversion_function *write_conversion_fn,
+			 MPI_Datarep_extent_function *dtype_file_extent_fn,
+			 void *extra_state)
 {
     int error_code;
-    ADIOI_Datarep *datarep;
+    ADIOI_Datarep *adio_datarep;
     static char myname[] = "MPI_REGISTER_DATAREP";
 
     MPIU_THREAD_CS_ENTER(ALLFUNC,);
@@ -63,9 +63,9 @@ int MPI_Register_datarep(MPICH2_CONST char *name,
     /* --BEGIN ERROR HANDLING-- */
     /* check datarep name (use strlen instead of strnlen because
        strnlen is not portable) */
-    if (name == NULL ||
-	strlen(name) < 1 || 
-	strlen(name) > MPI_MAX_DATAREP_STRING)
+    if (datarep == NULL ||
+	strlen(datarep) < 1 ||
+	strlen(datarep) > MPI_MAX_DATAREP_STRING)
     {
 	error_code = MPIO_Err_create_code(MPI_SUCCESS,
 					  MPIR_ERR_RECOVERABLE,
@@ -82,22 +82,22 @@ int MPI_Register_datarep(MPICH2_CONST char *name,
 
     /* --BEGIN ERROR HANDLING-- */
     /* check datarep isn't already registered */
-    for (datarep = ADIOI_Datarep_head; datarep; datarep = datarep->next) {
-	if (!strncmp(name, datarep->name, MPI_MAX_DATAREP_STRING)) {
+    for (adio_datarep = ADIOI_Datarep_head; adio_datarep; adio_datarep = adio_datarep->next) {
+	if (!strncmp(datarep, adio_datarep->name, MPI_MAX_DATAREP_STRING)) {
 	    error_code = MPIO_Err_create_code(MPI_SUCCESS,
 					      MPIR_ERR_RECOVERABLE,
 					      myname, __LINE__,
 					      MPI_ERR_DUP_DATAREP,
 					      "**datarepused",
 					      "**datarepused %s",
-					      name);
+					      datarep);
 	    error_code = MPIO_Err_return_file(MPI_FILE_NULL, error_code);
 	    goto fn_exit;
 	}
     }
 
     /* check extent function pointer */
-    if (extent_fn == NULL)
+    if (dtype_file_extent_fn == NULL)
     {
 	error_code = MPIO_Err_create_code(MPI_SUCCESS,
 					  MPIR_ERR_RECOVERABLE,
@@ -109,15 +109,15 @@ int MPI_Register_datarep(MPICH2_CONST char *name,
     }
     /* --END ERROR HANDLING-- */
 
-    datarep = ADIOI_Malloc(sizeof(ADIOI_Datarep));
-    datarep->name = ADIOI_Strdup(name);
-    datarep->state         = state;
-    datarep->read_conv_fn  = read_conv_fn;
-    datarep->write_conv_fn = write_conv_fn;
-    datarep->extent_fn     = extent_fn;
-    datarep->next          = ADIOI_Datarep_head;
+    adio_datarep = ADIOI_Malloc(sizeof(ADIOI_Datarep));
+    adio_datarep->name = ADIOI_Strdup(datarep);
+    adio_datarep->state         = extra_state;
+    adio_datarep->read_conv_fn  = read_conversion_fn;
+    adio_datarep->write_conv_fn = write_conversion_fn;
+    adio_datarep->extent_fn     = dtype_file_extent_fn;
+    adio_datarep->next          = ADIOI_Datarep_head;
 
-    ADIOI_Datarep_head = datarep;
+    ADIOI_Datarep_head = adio_datarep;
 
     error_code = MPI_SUCCESS;
 
