@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /* 
  *
  *   Copyright (C) 1997 University of Chicago. 
@@ -32,31 +32,33 @@ Input Parameters:
 
 .N fortran
 @*/
-int MPI_File_set_info(MPI_File mpi_fh, MPI_Info info)
+int MPI_File_set_info(MPI_File fh, MPI_Info info)
 {
     int error_code;
     static char myname[] = "MPI_FILE_SET_INFO";
-    ADIO_File fh;
+    ADIO_File adio_fh;
 
     MPIU_THREAD_CS_ENTER(ALLFUNC,);
 
-    fh = MPIO_File_resolve(mpi_fh);
+    adio_fh = MPIO_File_resolve(fh);
 
     /* --BEGIN ERROR HANDLING-- */
-    MPIO_CHECK_FILE_HANDLE(fh, myname, error_code);
+    MPIO_CHECK_FILE_HANDLE(adio_fh, myname, error_code);
+    MPIO_CHECK_INFO(info, error_code);
     /* --END ERROR HANDLING-- */
 
     /* set new info */
-    ADIO_SetInfo(fh, info, &error_code);
-    /* TODO: what to do with error code? */
-
-    /* --BEGIN ERROR HANDLING-- */
-    if (error_code != MPI_SUCCESS)
-	error_code = MPIO_Err_return_file(fh, error_code);
-    /* --END ERROR HANDLING-- */
+    ADIO_SetInfo(adio_fh, info, &error_code);
 
 fn_exit:
+    /* --BEGIN ERROR HANDLING-- */
+    if (error_code != MPI_SUCCESS)
+	error_code = MPIO_Err_return_file(adio_fh, error_code);
+    /* --END ERROR HANDLING-- */
+
     MPIU_THREAD_CS_EXIT(ALLFUNC,);
 
     return error_code;
+fn_fail:
+    goto fn_exit;
 }
