@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /* 
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -38,7 +38,7 @@ Output Parameters:
 
 .N fortran
 @*/
-int MPI_File_write(MPI_File mpi_fh, MPICH2_CONST void *buf, int count,
+int MPI_File_write(MPI_File fh, const void *buf, int count,
                    MPI_Datatype datatype, MPI_Status *status)
 {
     int error_code;
@@ -49,7 +49,7 @@ int MPI_File_write(MPI_File mpi_fh, MPICH2_CONST void *buf, int count,
     HPMP_IO_START(fl_xmpi, BLKMPIFILEWRITE, TRDTBLOCK, fh, datatype, count);
 #endif /* MPI_hpux */
 
-    error_code = MPIOI_File_write(mpi_fh, (MPI_Offset) 0, ADIO_INDIVIDUAL, buf,
+    error_code = MPIOI_File_write(fh, (MPI_Offset) 0, ADIO_INDIVIDUAL, buf,
 				  count, datatype, myname, status);
 
 #ifdef MPI_hpux
@@ -61,7 +61,7 @@ int MPI_File_write(MPI_File mpi_fh, MPICH2_CONST void *buf, int count,
 
 /* prevent multiple definitions of this routine */
 #ifdef MPIO_BUILD_PROFILING
-int MPIOI_File_write(MPI_File mpi_fh,
+int MPIOI_File_write(MPI_File fh,
 		     MPI_Offset offset,
 		     int file_ptr_type,
 		     const void *buf,
@@ -73,24 +73,25 @@ int MPIOI_File_write(MPI_File mpi_fh,
     int error_code, bufsize, buftype_is_contig, filetype_is_contig;
     int datatype_size;
     ADIO_Offset off;
-    ADIO_File fh;
-    void *e32buf=NULL, *xbuf=NULL;
+    ADIO_File adio_fh;
+    void *e32buf=NULL;
+    const void *xbuf=NULL;
 
     MPIU_THREAD_CS_ENTER(ALLFUNC,);
 
-    fh = MPIO_File_resolve(mpi_fh);
+    adio_fh = MPIO_File_resolve(fh);
 
     /* --BEGIN ERROR HANDLING-- */
-    MPIO_CHECK_FILE_HANDLE(fh, myname, error_code);
-    MPIO_CHECK_COUNT(fh, count, myname, error_code);
-    MPIO_CHECK_DATATYPE(fh, datatype, myname, error_code); 
+    MPIO_CHECK_FILE_HANDLE(adio_fh, myname, error_code);
+    MPIO_CHECK_COUNT(adio_fh, count, myname, error_code);
+    MPIO_CHECK_DATATYPE(adio_fh, datatype, myname, error_code);
 
     if (file_ptr_type == ADIO_EXPLICIT_OFFSET && offset < 0)
     {
 	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
 					  myname, __LINE__, MPI_ERR_ARG,
 					  "**iobadoffset", 0);
-	error_code = MPIO_Err_return_file(fh, error_code);
+	error_code = MPIO_Err_return_file(adio_fh, error_code);
 	goto fn_exit;
     }
     /* --END ERROR HANDLING-- */
@@ -98,7 +99,7 @@ int MPIOI_File_write(MPI_File mpi_fh,
     MPI_Type_size(datatype, &datatype_size);
 
     /* --BEGIN ERROR HANDLING-- */
-    MPIO_CHECK_COUNT_SIZE(fh, count, datatype_size, myname, error_code);
+    MPIO_CHECK_COUNT_SIZE(adio_fh, count, datatype_size, myname, error_code);
     /* --END ERROR HANDLING-- */
 
     if (count*datatype_size == 0)
@@ -111,18 +112,18 @@ int MPIOI_File_write(MPI_File mpi_fh,
     }
 
     /* --BEGIN ERROR HANDLING-- */
-    MPIO_CHECK_INTEGRAL_ETYPE(fh, count, datatype_size, myname, error_code);
-    MPIO_CHECK_WRITABLE(fh, myname, error_code);
-    MPIO_CHECK_NOT_SEQUENTIAL_MODE(fh, myname, error_code);
+    MPIO_CHECK_INTEGRAL_ETYPE(adio_fh, count, datatype_size, myname, error_code);
+    MPIO_CHECK_WRITABLE(adio_fh, myname, error_code);
+    MPIO_CHECK_NOT_SEQUENTIAL_MODE(adio_fh, myname, error_code);
     /* --END ERROR HANDLING-- */
 
     ADIOI_Datatype_iscontig(datatype, &buftype_is_contig);
-    ADIOI_Datatype_iscontig(fh->filetype, &filetype_is_contig);
+    ADIOI_Datatype_iscontig(adio_fh->filetype, &filetype_is_contig);
 
-    ADIOI_TEST_DEFERRED(fh, myname, &error_code);
+    ADIOI_TEST_DEFERRED(adio_fh, myname, &error_code);
 
-    xbuf = (void *)buf;
-    if (fh->is_external32) {
+    xbuf = buf;
+    if (adio_fh->is_external32) {
 	error_code = MPIU_external32_buffer_setup(buf, count, datatype, &e32buf);
 	if (error_code != MPI_SUCCESS) 
 	    goto fn_exit;
@@ -135,10 +136,10 @@ int MPIOI_File_write(MPI_File mpi_fh,
 	/* convert bufcount and offset to bytes */
 	bufsize = datatype_size * count;
 	if (file_ptr_type == ADIO_EXPLICIT_OFFSET) {
-	    off = fh->disp + fh->etype_size * offset;
+	    off = adio_fh->disp + adio_fh->etype_size * offset;
 	}
 	else /* ADIO_INDIVIDUAL */ {
-	    off = fh->fp_ind;
+	    off = adio_fh->fp_ind;
 	}
 
         /* if atomic mode requested, lock (exclusive) the region, because
@@ -147,30 +148,30 @@ int MPIOI_File_write(MPI_File mpi_fh,
            ADIO_WriteContig.
 	 */
 
-        if ((fh->atomicity) && ADIO_Feature(fh, ADIO_LOCKS))
+        if ((adio_fh->atomicity) && ADIO_Feature(adio_fh, ADIO_LOCKS))
 	{
-            ADIOI_WRITE_LOCK(fh, off, SEEK_SET, bufsize);
+            ADIOI_WRITE_LOCK(adio_fh, off, SEEK_SET, bufsize);
 	}
 
-	ADIO_WriteContig(fh, xbuf, count, datatype, file_ptr_type,
+	ADIO_WriteContig(adio_fh, xbuf, count, datatype, file_ptr_type,
 		     off, status, &error_code); 
 
-        if ((fh->atomicity) && ADIO_Feature(fh, ADIO_LOCKS))
+        if ((adio_fh->atomicity) && ADIO_Feature(adio_fh, ADIO_LOCKS))
 	{
-            ADIOI_UNLOCK(fh, off, SEEK_SET, bufsize);
+            ADIOI_UNLOCK(adio_fh, off, SEEK_SET, bufsize);
 	}
     }
     else
     {
 	/* For strided and atomic mode, locking is done in ADIO_WriteStrided */
-	ADIO_WriteStrided(fh, xbuf, count, datatype, file_ptr_type,
+	ADIO_WriteStrided(adio_fh, xbuf, count, datatype, file_ptr_type,
 			  offset, status, &error_code);
     }
 
 
     /* --BEGIN ERROR HANDLING-- */
     if (error_code != MPI_SUCCESS)
-	error_code = MPIO_Err_return_file(fh, error_code);
+	error_code = MPIO_Err_return_file(adio_fh, error_code);
     /* --END ERROR HANDLING-- */
 
 fn_exit:
