@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /* 
  *
  *   Copyright (C) 1997 University of Chicago. 
@@ -35,13 +35,13 @@ Input Parameters:
 
 .N fortran
 @*/
-int MPI_File_write_all_begin(MPI_File mpi_fh, MPICH2_CONST void *buf, int count,
+int MPI_File_write_all_begin(MPI_File fh, const void *buf, int count,
 			     MPI_Datatype datatype)
 {
     int error_code;
     static char myname[] = "MPI_FILE_WRITE_ALL_BEGIN";
 
-    error_code = MPIOI_File_write_all_begin(mpi_fh, (MPI_Offset) 0,
+    error_code = MPIOI_File_write_all_begin(fh, (MPI_Offset) 0,
 					    ADIO_INDIVIDUAL, buf, count,
 					    datatype, myname);
 
@@ -50,7 +50,7 @@ int MPI_File_write_all_begin(MPI_File mpi_fh, MPICH2_CONST void *buf, int count,
 
 /* prevent multiple definitions of this routine */
 #ifdef MPIO_BUILD_PROFILING
-int MPIOI_File_write_all_begin(MPI_File mpi_fh,
+int MPIOI_File_write_all_begin(MPI_File fh,
 			       MPI_Offset offset,
 			       int file_ptr_type,
 			       const void *buf,
@@ -59,49 +59,50 @@ int MPIOI_File_write_all_begin(MPI_File mpi_fh,
 			       char *myname)
 {
     int error_code, datatype_size;
-    ADIO_File fh;
-    void *e32buf=NULL, *xbuf=NULL;
+    ADIO_File adio_fh;
+    void *e32buf=NULL;
+    const void *xbuf=NULL;
 
     MPIU_THREAD_CS_ENTER(ALLFUNC,);
 
-    fh = MPIO_File_resolve(mpi_fh);
+    adio_fh = MPIO_File_resolve(fh);
 
     /* --BEGIN ERROR HANDLING-- */
-    MPIO_CHECK_FILE_HANDLE(fh, myname, error_code);
-    MPIO_CHECK_COUNT(fh, count, myname, error_code);
-    MPIO_CHECK_DATATYPE(fh, datatype, myname, error_code);
-    MPIO_CHECK_NOT_SEQUENTIAL_MODE(fh, myname, error_code);
+    MPIO_CHECK_FILE_HANDLE(adio_fh, myname, error_code);
+    MPIO_CHECK_COUNT(adio_fh, count, myname, error_code);
+    MPIO_CHECK_DATATYPE(adio_fh, datatype, myname, error_code);
+    MPIO_CHECK_NOT_SEQUENTIAL_MODE(adio_fh, myname, error_code);
 
     if (file_ptr_type == ADIO_EXPLICIT_OFFSET && offset < 0)
     {
 	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
 					  myname, __LINE__, MPI_ERR_ARG,
 					  "**iobadoffset", 0);
-	error_code = MPIO_Err_return_file(fh, error_code);
+	error_code = MPIO_Err_return_file(adio_fh, error_code);
 	goto fn_exit;
     }
 
-    if (fh->split_coll_count)
+    if (adio_fh->split_coll_count)
     {
 	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
 					  myname, __LINE__, MPI_ERR_IO, 
 					  "**iosplitcoll", 0);
-	error_code = MPIO_Err_return_file(fh, error_code);
+	error_code = MPIO_Err_return_file(adio_fh, error_code);
 	goto fn_exit;
     }
     /* --END ERROR HANDLING-- */
 
-    fh->split_coll_count = 1;
+    adio_fh->split_coll_count = 1;
 
     MPI_Type_size(datatype, &datatype_size);
     /* --BEGIN ERROR HANDLING-- */
-    MPIO_CHECK_INTEGRAL_ETYPE(fh, count, datatype_size, myname, error_code);
-    MPIO_CHECK_COUNT_SIZE(fh, count, datatype_size, myname, error_code);
+    MPIO_CHECK_INTEGRAL_ETYPE(adio_fh, count, datatype_size, myname, error_code);
+    MPIO_CHECK_COUNT_SIZE(adio_fh, count, datatype_size, myname, error_code);
     /* --END ERROR HANDLING-- */
 
 
-    xbuf = (void *)buf;
-    if (fh->is_external32) {
+    xbuf = buf;
+    if (adio_fh->is_external32) {
 	error_code = MPIU_external32_buffer_setup(buf, count, datatype, &e32buf);
 	if (error_code != MPI_SUCCESS) 
 	    goto fn_exit;
@@ -109,13 +110,13 @@ int MPIOI_File_write_all_begin(MPI_File mpi_fh,
 	xbuf = e32buf;
     }
 
-    fh->split_datatype = datatype;
-    ADIO_WriteStridedColl(fh, xbuf, count, datatype, file_ptr_type,
-			  offset, &fh->split_status, &error_code);
+    adio_fh->split_datatype = datatype;
+    ADIO_WriteStridedColl(adio_fh, xbuf, count, datatype, file_ptr_type,
+			  offset, &adio_fh->split_status, &error_code);
 
     /* --BEGIN ERROR HANDLING-- */
     if (error_code != MPI_SUCCESS)
-	error_code = MPIO_Err_return_file(fh, error_code);
+	error_code = MPIO_Err_return_file(adio_fh, error_code);
     /* --END ERROR HANDLING-- */
 
 fn_exit:
