@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /* 
  *
  *   Copyright (C) 1997 University of Chicago. 
@@ -39,30 +39,31 @@ Output Parameters:
 
 .N fortran
 @*/
-int MPI_File_write_shared(MPI_File mpi_fh, MPICH2_CONST void *buf, int count,
+int MPI_File_write_shared(MPI_File fh, const void *buf, int count,
                           MPI_Datatype datatype, MPI_Status *status)
 {
     int error_code, bufsize, buftype_is_contig, filetype_is_contig;
     static char myname[] = "MPI_FILE_READ_SHARED";
     int datatype_size, incr;
     ADIO_Offset off, shared_fp;
-    ADIO_File fh;
-    void *e32buf = NULL, *xbuf = NULL;
+    ADIO_File adio_fh;
+    void *e32buf = NULL;
+    const void *xbuf = NULL;
 
     MPIU_THREAD_CS_ENTER(ALLFUNC,);
 
-    fh = MPIO_File_resolve(mpi_fh);
+    adio_fh = MPIO_File_resolve(fh);
 
     /* --BEGIN ERROR HANDLING-- */
-    MPIO_CHECK_FILE_HANDLE(fh, myname, error_code);
-    MPIO_CHECK_COUNT(fh, count, myname, error_code);
-    MPIO_CHECK_DATATYPE(fh, datatype, myname, error_code);
+    MPIO_CHECK_FILE_HANDLE(adio_fh, myname, error_code);
+    MPIO_CHECK_COUNT(adio_fh, count, myname, error_code);
+    MPIO_CHECK_DATATYPE(adio_fh, datatype, myname, error_code);
     /* --END ERROR HANDLING-- */
 
     MPI_Type_size(datatype, &datatype_size);
 
     /* --BEGIN ERROR HANDLING-- */
-    MPIO_CHECK_COUNT_SIZE(fh, count, datatype_size, myname, error_code);
+    MPIO_CHECK_COUNT_SIZE(adio_fh, count, datatype_size, myname, error_code);
     /* --END ERROR HANDLING-- */
 
     if (count*datatype_size == 0) {
@@ -74,31 +75,31 @@ int MPI_File_write_shared(MPI_File mpi_fh, MPICH2_CONST void *buf, int count,
     }
 
     /* --BEGIN ERROR HANDLING-- */
-    MPIO_CHECK_INTEGRAL_ETYPE(fh, count, datatype_size, myname, error_code);
-    MPIO_CHECK_FS_SUPPORTS_SHARED(fh, myname, error_code);
+    MPIO_CHECK_INTEGRAL_ETYPE(adio_fh, count, datatype_size, myname, error_code);
+    MPIO_CHECK_FS_SUPPORTS_SHARED(adio_fh, myname, error_code);
     /* --END ERROR HANDLING-- */
 
     ADIOI_Datatype_iscontig(datatype, &buftype_is_contig);
-    ADIOI_Datatype_iscontig(fh->filetype, &filetype_is_contig);
+    ADIOI_Datatype_iscontig(adio_fh->filetype, &filetype_is_contig);
 
-    ADIOI_TEST_DEFERRED(fh, myname, &error_code);
+    ADIOI_TEST_DEFERRED(adio_fh, myname, &error_code);
 
-    incr = (count*datatype_size)/fh->etype_size;
+    incr = (count*datatype_size)/adio_fh->etype_size;
 
-    ADIO_Get_shared_fp(fh, incr, &shared_fp, &error_code);
+    ADIO_Get_shared_fp(adio_fh, incr, &shared_fp, &error_code);
     /* --BEGIN ERROR HANDLING-- */
     if (error_code != MPI_SUCCESS)
     {
 	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_FATAL,
 					  myname, __LINE__, MPI_ERR_INTERN, 
 					  "**iosharedfailed", 0);
-	error_code = MPIO_Err_return_file(fh, error_code);
+	error_code = MPIO_Err_return_file(adio_fh, error_code);
 	goto fn_exit;
     }
     /* --END ERROR HANDLING-- */
 
     xbuf = buf;
-    if (fh->is_external32) {
+    if (adio_fh->is_external32) {
 	error_code = MPIU_external32_buffer_setup(buf, count, datatype, &e32buf);
 	if (error_code != MPI_SUCCESS) 
 	    goto fn_exit;
@@ -110,31 +111,31 @@ int MPI_File_write_shared(MPI_File mpi_fh, MPICH2_CONST void *buf, int count,
     {
         /* convert bufocunt and shared_fp to bytes */
 	bufsize = datatype_size * count;
-	off = fh->disp + fh->etype_size * shared_fp;
+	off = adio_fh->disp + adio_fh->etype_size * shared_fp;
 
         /* if atomic mode requested, lock (exclusive) the region, because there
            could be a concurrent noncontiguous request. On NFS, locking is 
            done in the ADIO_WriteContig.*/
 
-        if ((fh->atomicity) && (fh->file_system != ADIO_NFS))
-            ADIOI_WRITE_LOCK(fh, off, SEEK_SET, bufsize);
+        if ((adio_fh->atomicity) && (adio_fh->file_system != ADIO_NFS))
+            ADIOI_WRITE_LOCK(adio_fh, off, SEEK_SET, bufsize);
 
-	ADIO_WriteContig(fh, xbuf, count, datatype, ADIO_EXPLICIT_OFFSET,
+	ADIO_WriteContig(adio_fh, xbuf, count, datatype, ADIO_EXPLICIT_OFFSET,
 		     off, status, &error_code); 
 
-        if ((fh->atomicity) && (fh->file_system != ADIO_NFS))
-            ADIOI_UNLOCK(fh, off, SEEK_SET, bufsize);
+        if ((adio_fh->atomicity) && (adio_fh->file_system != ADIO_NFS))
+            ADIOI_UNLOCK(adio_fh, off, SEEK_SET, bufsize);
     }
     else
     {
-	ADIO_WriteStrided(fh, xbuf, count, datatype, ADIO_EXPLICIT_OFFSET,
+	ADIO_WriteStrided(adio_fh, xbuf, count, datatype, ADIO_EXPLICIT_OFFSET,
 			 shared_fp, status, &error_code);
 	/* For strided and atomic mode, locking is done in ADIO_WriteStrided */
     }
 
     /* --BEGIN ERROR HANDLING-- */
     if (error_code != MPI_SUCCESS)
-	error_code = MPIO_Err_return_file(fh, error_code);
+	error_code = MPIO_Err_return_file(adio_fh, error_code);
     /* --END ERROR HANDLING-- */
 
 fn_exit:
