@@ -51,7 +51,7 @@ Input Parameters:
 . info - hints on optimization and interpretation of weights (handle)
 - reorder - the process may be reordered (true) or not (false) (logical)
 
-Output Parameter:
+Output Parameters:
 . comm_dist_graph - communicator with distributed graph topology added (handle)
 
 .N ThreadSafe
@@ -63,9 +63,9 @@ Output Parameter:
 .N MPI_ERR_ARG
 .N MPI_ERR_OTHER
 @*/
-int MPI_Dist_graph_create(MPI_Comm comm_old, int n, MPICH2_CONST int sources[],
-                          MPICH2_CONST int degrees[], MPICH2_CONST int destinations[],
-                          MPICH2_CONST int weights[],
+int MPI_Dist_graph_create(MPI_Comm comm_old, int n, const int sources[],
+                          const int degrees[], const int destinations[],
+                          const int weights[],
                           MPI_Info info, int reorder, MPI_Comm *comm_dist_graph)
 {
     int mpi_errno = MPI_SUCCESS;
