@@ -6,21 +6,21 @@
 
 #include "mpiimpl.h"
 
-/* -- Begin Profiling Symbol Block for routine MPIX_T_cvar_handle_free */
+/* -- Begin Profiling Symbol Block for routine MPI_T_cvar_handle_free */
 #if defined(HAVE_PRAGMA_WEAK)
-#pragma weak MPIX_T_cvar_handle_free = PMPIX_T_cvar_handle_free
+#pragma weak MPI_T_cvar_handle_free = PMPI_T_cvar_handle_free
 #elif defined(HAVE_PRAGMA_HP_SEC_DEF)
-#pragma _HP_SECONDARY_DEF PMPIX_T_cvar_handle_free  MPIX_T_cvar_handle_free
+#pragma _HP_SECONDARY_DEF PMPI_T_cvar_handle_free  MPI_T_cvar_handle_free
 #elif defined(HAVE_PRAGMA_CRI_DUP)
-#pragma _CRI duplicate MPIX_T_cvar_handle_free as PMPIX_T_cvar_handle_free
+#pragma _CRI duplicate MPI_T_cvar_handle_free as PMPI_T_cvar_handle_free
 #endif
 /* -- End Profiling Symbol Block */
 
 /* Define MPICH_MPI_FROM_PMPI if weak symbols are not supported to build
    the MPI routines */
 #ifndef MPICH_MPI_FROM_PMPI
-#undef MPIX_T_cvar_handle_free
-#define MPIX_T_cvar_handle_free PMPIX_T_cvar_handle_free
+#undef MPI_T_cvar_handle_free
+#define MPI_T_cvar_handle_free PMPI_T_cvar_handle_free
 
 /* any non-MPI functions go here, especially non-static ones */
 
@@ -28,12 +28,12 @@
 #define FUNCNAME MPIR_T_cvar_handle_free_impl
 #undef FCNAME
 #define FCNAME MPIU_QUOTE(FUNCNAME)
-int MPIR_T_cvar_handle_free_impl(MPIX_T_cvar_handle *handle)
+int MPIR_T_cvar_handle_free_impl(MPI_T_cvar_handle *handle)
 {
     int mpi_errno = MPI_SUCCESS;
 
     MPIU_Free(*handle);
-    *handle = MPIX_T_CVAR_HANDLE_NULL;
+    *handle = MPI_T_CVAR_HANDLE_NULL;
 
 fn_exit:
     return mpi_errno;
@@ -44,11 +44,11 @@ fn_fail:
 #endif /* MPICH_MPI_FROM_PMPI */
 
 #undef FUNCNAME
-#define FUNCNAME MPIX_T_cvar_handle_free
+#define FUNCNAME MPI_T_cvar_handle_free
 #undef FCNAME
 #define FCNAME MPIU_QUOTE(FUNCNAME)
 /*@
-MPIX_T_cvar_handle_free - XXX description here
+MPI_T_cvar_handle_free - XXX description here
 
 Input/Output Parameters:
 . handle - handle to be freed (handle)
@@ -59,13 +59,13 @@ Input/Output Parameters:
 
 .N Errors
 @*/
-int MPIX_T_cvar_handle_free(MPIX_T_cvar_handle *handle)
+int MPI_T_cvar_handle_free(MPI_T_cvar_handle *handle)
 {
     int mpi_errno = MPI_SUCCESS;
-    MPID_MPI_STATE_DECL(MPID_STATE_MPIX_T_CVAR_HANDLE_FREE);
+    MPID_MPI_STATE_DECL(MPID_STATE_MPI_T_CVAR_HANDLE_FREE);
 
     MPIU_THREAD_CS_ENTER(ALLFUNC,);
-    MPID_MPI_FUNC_ENTER(MPID_STATE_MPIX_T_CVAR_HANDLE_FREE);
+    MPID_MPI_FUNC_ENTER(MPID_STATE_MPI_T_CVAR_HANDLE_FREE);
 
     /* Validate parameters, especially handles needing to be converted */
 #   ifdef HAVE_ERROR_CHECKING
@@ -102,7 +102,7 @@ int MPIX_T_cvar_handle_free(MPIX_T_cvar_handle *handle)
     /* ... end of body of routine ... */
 
 fn_exit:
-    MPID_MPI_FUNC_EXIT(MPID_STATE_MPIX_T_CVAR_HANDLE_FREE);
+    MPID_MPI_FUNC_EXIT(MPID_STATE_MPI_T_CVAR_HANDLE_FREE);
     MPIU_THREAD_CS_EXIT(ALLFUNC,);
     return mpi_errno;
 
@@ -112,7 +112,7 @@ fn_fail:
     {
         mpi_errno = MPIR_Err_create_code(
             mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER,
-            "**mpix_t_cvar_handle_free", "**mpix_t_cvar_handle_free %p", handle);
+            "**mpi_t_cvar_handle_free", "**mpi_t_cvar_handle_free %p", handle);
     }
 #   endif
     mpi_errno = MPIR_Err_return_comm(NULL, FCNAME, mpi_errno);
