@@ -6,21 +6,21 @@
 
 #include "mpiimpl.h"
 
-/* -- Begin Profiling Symbol Block for routine MPIX_T_enum_get_info */
+/* -- Begin Profiling Symbol Block for routine MPI_T_enum_get_info */
 #if defined(HAVE_PRAGMA_WEAK)
-#pragma weak MPIX_T_enum_get_info = PMPIX_T_enum_get_info
+#pragma weak MPI_T_enum_get_info = PMPI_T_enum_get_info
 #elif defined(HAVE_PRAGMA_HP_SEC_DEF)
-#pragma _HP_SECONDARY_DEF PMPIX_T_enum_get_info  MPIX_T_enum_get_info
+#pragma _HP_SECONDARY_DEF PMPI_T_enum_get_info  MPI_T_enum_get_info
 #elif defined(HAVE_PRAGMA_CRI_DUP)
-#pragma _CRI duplicate MPIX_T_enum_get_info as PMPIX_T_enum_get_info
+#pragma _CRI duplicate MPI_T_enum_get_info as PMPI_T_enum_get_info
 #endif
 /* -- End Profiling Symbol Block */
 
 /* Define MPICH_MPI_FROM_PMPI if weak symbols are not supported to build
    the MPI routines */
 #ifndef MPICH_MPI_FROM_PMPI
-#undef MPIX_T_enum_get_info
-#define MPIX_T_enum_get_info PMPIX_T_enum_get_info
+#undef MPI_T_enum_get_info
+#define MPI_T_enum_get_info PMPI_T_enum_get_info
 
 /* any non-MPI functions go here, especially non-static ones */
 
@@ -28,7 +28,7 @@
 #define FUNCNAME MPIR_T_enum_get_info_impl
 #undef FCNAME
 #define FCNAME MPIU_QUOTE(FUNCNAME)
-int MPIR_T_enum_get_info_impl(MPIX_T_enum enumtype, int num, char *name, int *name_len)
+int MPIR_T_enum_get_info_impl(MPI_T_enum enumtype, int *num, char *name, int *name_len)
 {
     int mpi_errno = MPI_SUCCESS;
 
@@ -43,11 +43,11 @@ fn_fail:
 #endif /* MPICH_MPI_FROM_PMPI */
 
 #undef FUNCNAME
-#define FUNCNAME MPIX_T_enum_get_info
+#define FUNCNAME MPI_T_enum_get_info
 #undef FCNAME
 #define FCNAME MPIU_QUOTE(FUNCNAME)
 /*@
-MPIX_T_enum_get_info - XXX description here
+MPI_T_enum_get_info - XXX description here
 
 Input/Output Parameters:
 . name_len - length of the string and/or buffer for name (integer)
@@ -65,13 +65,13 @@ Output Parameters:
 
 .N Errors
 @*/
-int MPIX_T_enum_get_info(MPIX_T_enum enumtype, int num, char *name, int *name_len)
+int MPI_T_enum_get_info(MPI_T_enum enumtype, int *num, char *name, int *name_len)
 {
     int mpi_errno = MPI_SUCCESS;
-    MPID_MPI_STATE_DECL(MPID_STATE_MPIX_T_ENUM_GET_INFO);
+    MPID_MPI_STATE_DECL(MPID_STATE_MPI_T_ENUM_GET_INFO);
 
     MPIU_THREAD_CS_ENTER(ALLFUNC,);
-    MPID_MPI_FUNC_ENTER(MPID_STATE_MPIX_T_ENUM_GET_INFO);
+    MPID_MPI_FUNC_ENTER(MPID_STATE_MPI_T_ENUM_GET_INFO);
 
     /* Validate parameters, especially handles needing to be converted */
 #   ifdef HAVE_ERROR_CHECKING
@@ -93,8 +93,9 @@ int MPIX_T_enum_get_info(MPIX_T_enum enumtype, int num, char *name, int *name_le
     {
         MPID_BEGIN_ERROR_CHECKS
         {
-            MPIR_ERRTEST_ARGNULL(name_len, "name_len", mpi_errno);
+            MPIR_ERRTEST_ARGNULL(num, "num", mpi_errno);
             /* TODO more checks may be appropriate (counts, in_place, buffer aliasing, etc) */
+            if (mpi_errno != MPI_SUCCESS) goto fn_fail;
         }
         MPID_END_ERROR_CHECKS
     }
@@ -108,7 +109,7 @@ int MPIX_T_enum_get_info(MPIX_T_enum enumtype, int num, char *name, int *name_le
     /* ... end of body of routine ... */
 
 fn_exit:
-    MPID_MPI_FUNC_EXIT(MPID_STATE_MPIX_T_ENUM_GET_INFO);
+    MPID_MPI_FUNC_EXIT(MPID_STATE_MPI_T_ENUM_GET_INFO);
     MPIU_THREAD_CS_EXIT(ALLFUNC,);
     return mpi_errno;
 
@@ -118,7 +119,7 @@ fn_fail:
     {
         mpi_errno = MPIR_Err_create_code(
             mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER,
-            "**mpix_t_enum_get_info", "**mpix_t_enum_get_info %p %d %p %p", enumtype, num, name, name_len);
+            "**mpi_t_enum_get_info", "**mpi_t_enum_get_info %p %p %p %p", enumtype, num, name, name_len);
     }
 #   endif
     mpi_errno = MPIR_Err_return_comm(NULL, FCNAME, mpi_errno);
