@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -79,102 +79,50 @@ int MPID_nem_lmt_vmsplice_vc_terminated(MPIDI_VC_t *vc);
 
 int MPID_nem_handle_pkt(MPIDI_VC_t *vc, char *buf, MPIDI_msg_sz_t buflen);
 
-/* macro to access the channel_private fields in the vc */
-#define VC_CH(vc) ((MPIDI_CH3I_VC *)(vc)->channel_private)
-
-struct MPIDI_VC;
-struct MPID_Request;
-struct MPID_nem_copy_buf;
-union MPIDI_CH3_Pkt;
-struct MPID_nem_lmt_shm_wait_element;
-
-typedef struct MPIDI_CH3I_VC
-{
-    int pg_rank;
-    struct MPID_Request *recv_active;
-
-    int is_local;
-    unsigned short send_seqno;
-    MPID_nem_fbox_mpich2_t *fbox_out;
-    MPID_nem_fbox_mpich2_t *fbox_in;
-    MPID_nem_queue_ptr_t recv_queue;
-    MPID_nem_queue_ptr_t free_queue;
-
-#ifdef ENABLE_CHECKPOINTING
-    MPIDI_msg_sz_t ckpt_msg_len;
-    void *ckpt_msg_buf;
-#endif
-
-    /* temp buffer to store partially received header */
-    MPIDI_msg_sz_t pending_pkt_len;
-    union MPIDI_CH3_Pkt *pending_pkt;
-
-    /* can be used by netmods to put this vc on a send queue or list */
-    struct MPIDI_VC *next;
-    struct MPIDI_VC *prev;
-
-    /* contig function pointers.  Netmods should set these. */
-    /* iStartContigMsg -- sends a message consisting of a header (hdr) and contiguous data (data), possibly of 0 size.  If the
-       message cannot be sent immediately, the function should create a request and return a pointer in sreq_ptr.  The network
-       module should complete the request once the message has been completely sent. */
-    int (* iStartContigMsg)(struct MPIDI_VC *vc, void *hdr, MPIDI_msg_sz_t hdr_sz, void *data, MPIDI_msg_sz_t data_sz,
-                            struct MPID_Request **sreq_ptr);
-    /* iSentContig -- sends a message consisting of a header (hdr) and contiguous data (data), possibly of 0 size.  The
-       network module should complete the request once the message has been completely sent. */
-    int (* iSendContig)(struct MPIDI_VC *vc, struct MPID_Request *sreq, void *hdr, MPIDI_msg_sz_t hdr_sz,
-                        void *data, MPIDI_msg_sz_t data_sz);
-
-#ifdef ENABLE_CHECKPOINTING
-    /* ckpt_pause_send -- netmod should stop sending on this vc and queue messages to be sent after ckpt_continue()*/
-    int (* ckpt_pause_send_vc)(struct MPIDI_VC *vc);
-    /* ckpt_continue -- Notify remote side to start sending again. */
-    int (* ckpt_continue_vc)(struct MPIDI_VC *vc);
-    /* ckpt_restart -- similar to ckpt_continue, except that the process has been restarted */
-    int (* ckpt_restart_vc)(struct MPIDI_VC *vc);
-#endif
-
-    /* LMT function pointers */
-    int (* lmt_initiate_lmt)(struct MPIDI_VC *vc, union MPIDI_CH3_Pkt *rts_pkt, struct MPID_Request *req);
-    int (* lmt_start_recv)(struct MPIDI_VC *vc, struct MPID_Request *req, MPID_IOV s_cookie);
-    int (* lmt_start_send)(struct MPIDI_VC *vc, struct MPID_Request *sreq, MPID_IOV r_cookie);
-    int (* lmt_handle_cookie)(struct MPIDI_VC *vc, struct MPID_Request *req, MPID_IOV cookie);
-    int (* lmt_done_send)(struct MPIDI_VC *vc, struct MPID_Request *req);
-    int (* lmt_done_recv)(struct MPIDI_VC *vc, struct MPID_Request *req);
-    int (* lmt_vc_terminated)(struct MPIDI_VC *vc);
-
-    /* LMT shared memory copy-buffer ptr */
-    struct MPID_nem_copy_buf *lmt_copy_buf;
-    MPIU_SHMW_Hnd_t lmt_copy_buf_handle;
-    MPIU_SHMW_Hnd_t lmt_recv_copy_buf_handle;
-    int lmt_buf_num;
-    MPIDI_msg_sz_t lmt_surfeit;
-    struct {struct MPID_nem_lmt_shm_wait_element *head, *tail;} lmt_queue;
-    struct MPID_nem_lmt_shm_wait_element *lmt_active_lmt;
-    int lmt_enqueued; /* FIXME: used for debugging */
-
-    /* Pointer to per-vc packet handlers */
-    MPIDI_CH3_PktHandler_Fcn **pkt_handler;
-    int num_pkt_handlers;
-    
-    union
-    {
-        char padding[MPID_NEM_VC_NETMOD_AREA_LEN];
-
-        /* Temporary helper field for ticket #1679.  Should force proper pointer
-         * alignment on finnicky platforms like SPARC.  Proper fix is to stop
-         * this questionable type aliasing altogether. */
-        void *align_helper;
-    } netmod_area;
-    
-
-    /* FIXME: ch3 assumes there is a field called sendq_head in the ch
-       portion of the vc.  This is unused in nemesis and should be set
-       to NULL */
-    void *sendq_head;
-} MPIDI_CH3I_VC;
-
 /* Nemesis-provided RMA implementation */
 int MPIDI_CH3_SHM_Win_shared_query(MPID_Win *win_ptr, int target_rank, MPI_Aint *size, int *disp_unit, void *baseptr);
 int MPIDI_CH3_SHM_Win_free(MPID_Win **win_ptr);
 
+/* Shared memory window atomic/accumulate mutex implementation */
+
+#define MPIDI_CH3I_SHM_MUTEX_LOCK(win_ptr)                                              \
+    do {                                                                                \
+        int pt_err = pthread_mutex_lock((win_ptr)->shm_mutex);                          \
+        MPIU_ERR_CHKANDJUMP1(pt_err, mpi_errno, MPI_ERR_OTHER, "**pthread_lock",        \
+                             "**pthread_lock %s", strerror(pt_err));                    \
+    } while (0)
+
+#define MPIDI_CH3I_SHM_MUTEX_UNLOCK(win_ptr)                                            \
+    do {                                                                                \
+        int pt_err = pthread_mutex_unlock((win_ptr)->shm_mutex);                        \
+        MPIU_ERR_CHKANDJUMP1(pt_err, mpi_errno, MPI_ERR_OTHER, "**pthread_unlock",      \
+                             "**pthread_unlock %s", strerror(pt_err));                  \
+    } while (0)
+
+#define MPIDI_CH3I_SHM_MUTEX_INIT(win_ptr)                                              \
+    do {                                                                                \
+        int pt_err;                                                                     \
+        pthread_mutexattr_t attr;                                                       \
+                                                                                        \
+        pt_err = pthread_mutexattr_init(&attr);                                         \
+        MPIU_ERR_CHKANDJUMP1(pt_err, mpi_errno, MPI_ERR_OTHER, "**pthread_mutex",       \
+                             "**pthread_mutex %s", strerror(pt_err));                   \
+        pt_err = pthread_mutexattr_setpshared(&attr, PTHREAD_PROCESS_SHARED);           \
+        MPIU_ERR_CHKANDJUMP1(pt_err, mpi_errno, MPI_ERR_OTHER, "**pthread_mutex",       \
+                             "**pthread_mutex %s", strerror(pt_err));                   \
+        pt_err = pthread_mutex_init((win_ptr)->shm_mutex, &attr);                       \
+        MPIU_ERR_CHKANDJUMP1(pt_err, mpi_errno, MPI_ERR_OTHER, "**pthread_mutex",       \
+                             "**pthread_mutex %s", strerror(pt_err));                   \
+        pt_err = pthread_mutexattr_destroy(&attr);                                      \
+        MPIU_ERR_CHKANDJUMP1(pt_err, mpi_errno, MPI_ERR_OTHER, "**pthread_mutex",       \
+                             "**pthread_mutex %s", strerror(pt_err));                   \
+    } while (0);
+
+#define MPIDI_CH3I_SHM_MUTEX_DESTROY(win_ptr)                                           \
+    do {                                                                                \
+        int pt_err = pthread_mutex_destroy((win_ptr)->shm_mutex);                       \
+        MPIU_ERR_CHKANDJUMP1(pt_err, mpi_errno, MPI_ERR_OTHER, "**pthread_mutex",       \
+                             "**pthread_mutex %s", strerror(pt_err));                   \
+    } while (0);
+
 #endif /* !defined(MPICH_MPIDI_CH3_IMPL_H_INCLUDED) */
