@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -48,31 +48,21 @@ int MPIDI_CH3_ReqHandler_GetSendRespComplete( MPIDI_VC_t *vc ATTRIBUTE((unused))
 					      int *complete )
 {
     int mpi_errno = MPI_SUCCESS;
+    MPID_Win *win_ptr;
 
-    /* FIXME: Should this test be an MPIU_Assert? */
-    if (sreq->dev.source_win_handle != MPI_WIN_NULL) {
-	MPID_Win *win_ptr;
-	/* Last RMA operation (get) from source. If active target RMA,
-	   decrement window counter. If passive target RMA, 
-	   release lock on window and grant next lock in the 
-	   lock queue if there is any; no need to send rma done 
-	   packet since the last operation is a get. */
-	
-	MPID_Win_get_ptr(sreq->dev.target_win_handle, win_ptr);
-	if (win_ptr->current_lock_type == MPID_LOCK_NONE) {
-	    /* FIXME: MT: this has to be done atomically */
-	    win_ptr->my_counter -= 1;
-	}
-	else {
-	    mpi_errno = MPIDI_CH3I_Release_lock(win_ptr);
-	}
-    }
+    MPID_Win_get_ptr(sreq->dev.target_win_handle, win_ptr);
+
+    mpi_errno = MPIDI_CH3_Finish_rma_op_target(NULL, win_ptr, FALSE, sreq->dev.flags, MPI_WIN_NULL);
+    if (mpi_errno) { MPIU_ERR_POP(mpi_errno); }
 
     /* mark data transfer as complete and decrement CC */
     MPIDI_CH3U_Request_complete(sreq);
     *complete = TRUE;
 
+ fn_exit:
     return mpi_errno;
+ fn_fail:
+    goto fn_exit;
 }
 
 int MPIDI_CH3_ReqHandler_SendReloadIOV( MPIDI_VC_t *vc ATTRIBUTE((unused)), MPID_Request *sreq, 
