@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -1136,7 +1136,7 @@ fn_fail:
    new intercommunicator
 -  remote_pg - array of remote process groups
 
-   Input/Output Parameter:
+Input/Output Parameters:
 .  intercomm - New intercommunicator.  The intercommunicator must already
    have been allocated; this routine initializes many of the fields
 
