@@ -1,10 +1,11 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
  */
 
 #include "mpidimpl.h"
+#include "mpidi_recvq_statistics.h"
 
 /* MPIDI_POSTED_RECV_ENQUEUE_HOOK(req): Notifies channel that req has
    been enqueued on the posted recv queue.  Returns void. */
@@ -50,7 +51,7 @@ static MPID_Request * recvq_unexpected_tail = 0;
 /* Export the location of the queue heads if debugger support is enabled.
  * This allows the queue code to rely on the local variables for the
  * queue heads while also exporting those variables to the debugger.
- * See src/mpi/debugger/dll_mpich2.c for how this is used to 
+ * See src/mpi/debugger/dll_mpich.c for how this is used to 
  * access the message queues.
  */
 #ifdef HAVE_DEBUGGER_SUPPORT
@@ -58,25 +59,17 @@ MPID_Request ** const MPID_Recvq_posted_head_ptr     = &recvq_posted_head;
 MPID_Request ** const MPID_Recvq_unexpected_head_ptr = &recvq_unexpected_head;
 #endif
 
-/* TODO decide control this independently via configure or with the existing
- * --enable-timing option (#ifdef COLLECT_STATS) */
-#define ENABLE_RECVQ_STATISTICS 1
-#ifdef ENABLE_RECVQ_STATISTICS
+/* Always define these, since our macros will always generate references to
+ * them.  Every compiler we have tested optimizes these "if(0){...}" code paths
+ * away, even at "-O0". */
 static unsigned int posted_qlen = 0;
 static unsigned int unexpected_qlen = 0;
 static MPI_Aint posted_recvq_match_attempts = 0;
 static MPI_Aint unexpected_recvq_match_attempts = 0;
-/* TODO add some code here and probably elsewhere to make these show up in the
- * MPIX_T_pvar_ interface */
-#define MPIR_T_INC(x) (++(x))
-#define MPIR_T_DEC(x) (--(x))
+static double time_failed_matching_postedq = 0.0;
+static double time_matching_unexpectedq = 0.0;
+uint64_t MPIDI_CH3I_unexpected_recvq_buffer_size = 0;    /* used in ch3u_eager.c and ch3u_handle_recv_pkt.c */
 
-#else
-
-#define MPIR_T_INC(x)
-#define MPIR_T_DEC(x)
-
-#endif /* defined(ENABLE_RECVQ_STATISTICS) */
 
 /* If the MPIDI_Message_match structure fits into a pointer size, we
  * can directly work on it */
@@ -110,51 +103,28 @@ static MPI_Aint unexpected_recvq_match_attempts = 0;
       (((match1).parts.tag & (mask).parts.tag) == ((match2).parts.tag & (mask).parts.tag)) && \
       ((match1).parts.context_id == (match2).parts.context_id)))
 
+
 /* will be invoked to populate the custom parts of pvar_handle objects */
-static int simple_uint_creator(void *obj_handle,
-                               struct MPIR_T_pvar_handle *handle,
-                               int *countp)
-{
-    /* the IMPL_SIMPLE code reads/writes "bytes" bytes from the location given
-     * by the "handle_state" pointer */
-    handle->handle_state = handle->info->var_state;
-    handle->bytes = sizeof(unsigned int);
-
-    /* a single unsigned int should be read/written */
-    *countp = 1;
-    return MPI_SUCCESS;
-}
-
-static int simple_aint_creator(void *obj_handle,
-                               struct MPIR_T_pvar_handle *handle,
-                               int *countp)
-{
-    /* the IMPL_SIMPLE code reads/writes "bytes" bytes from the location given
-     * by the "handle_state" pointer */
-    handle->handle_state = handle->info->var_state;
-    handle->bytes = sizeof(MPI_Aint);
-
-    /* a single Aint should be read/written */
-    *countp = 1;
-    return MPI_SUCCESS;
-}
+MPIR_T_SIMPLE_HANDLE_CREATOR(simple_aint_creator, MPI_Aint, 1)
+MPIR_T_SIMPLE_HANDLE_CREATOR(simple_uint_creator, unsigned int, 1)
+MPIR_T_SIMPLE_HANDLE_CREATOR(simple_double_creator, double, 1)
 
 #undef FUNCNAME
-#define FUNCNAME MPIDI_CH3U_Recvq_FU
+#define FUNCNAME MPIDI_CH3U_Recvq_init
 #undef FCNAME
 #define FCNAME MPIU_QUOTE(FUNCNAME)
 int MPIDI_CH3U_Recvq_init(void)
 {
     int mpi_errno = MPI_SUCCESS;
-#ifdef ENABLE_RECVQ_STATISTICS
+#if ENABLE_RECVQ_STATISTICS
     int idx = -1;
     mpi_errno = MPIR_T_pvar_add("posted_recvq_length",
-                                MPIX_T_VERBOSITY_USER_DETAIL,
-                                MPIX_T_PVAR_CLASS_LEVEL,
+                                MPI_T_VERBOSITY_USER_DETAIL,
+                                MPI_T_PVAR_CLASS_LEVEL,
                                 MPI_UNSIGNED,
-                                MPIX_T_ENUM_NULL,
+                                MPI_T_ENUM_NULL,
                                 "length of the posted message receive queue",
-                                MPIX_T_BIND_NO_OBJECT,
+                                MPI_T_BIND_NO_OBJECT,
                                 /*readonly=*/TRUE,
                                 /*continuous=*/TRUE,
                                 /*atomic=*/FALSE,
@@ -165,12 +135,12 @@ int MPIDI_CH3U_Recvq_init(void)
     if (mpi_errno) MPIU_ERR_POP(mpi_errno);
 
     mpi_errno = MPIR_T_pvar_add("unexpected_recvq_length",
-                                MPIX_T_VERBOSITY_USER_DETAIL,
-                                MPIX_T_PVAR_CLASS_LEVEL,
+                                MPI_T_VERBOSITY_USER_DETAIL,
+                                MPI_T_PVAR_CLASS_LEVEL,
                                 MPI_UNSIGNED,
-                                MPIX_T_ENUM_NULL,
-                                "length of the unexpected messsage receive queue",
-                                MPIX_T_BIND_NO_OBJECT,
+                                MPI_T_ENUM_NULL,
+                                "length of the unexpected message receive queue",
+                                MPI_T_BIND_NO_OBJECT,
                                 /*readonly=*/TRUE,
                                 /*continuous=*/TRUE,
                                 /*atomic=*/FALSE,
@@ -182,12 +152,12 @@ int MPIDI_CH3U_Recvq_init(void)
 
     /* posted receive queue failed matches */
     mpi_errno = MPIR_T_pvar_add("posted_recvq_match_attempts",
-                                MPIX_T_VERBOSITY_USER_DETAIL,
-                                MPIX_T_PVAR_CLASS_COUNTER,
+                                MPI_T_VERBOSITY_USER_DETAIL,
+                                MPI_T_PVAR_CLASS_COUNTER,
                                 MPI_AINT,
-                                MPIX_T_ENUM_NULL,
-                                "number of search passes on the messsage receive queue",
-                                MPIX_T_BIND_NO_OBJECT,
+                                MPI_T_ENUM_NULL,
+                                "number of search passes on the message receive queue",
+                                MPI_T_BIND_NO_OBJECT,
                                 /*readonly=*/FALSE,
                                 /*continuous=*/TRUE,
                                 /*atomic=*/FALSE,
@@ -199,12 +169,12 @@ int MPIDI_CH3U_Recvq_init(void)
 
     /* unexpected receive queue failed matches */
     mpi_errno = MPIR_T_pvar_add("unexpected_recvq_match_attempts",
-                                MPIX_T_VERBOSITY_USER_DETAIL,
-                                MPIX_T_PVAR_CLASS_COUNTER,
+                                MPI_T_VERBOSITY_USER_DETAIL,
+                                MPI_T_PVAR_CLASS_COUNTER,
                                 MPI_AINT,
-                                MPIX_T_ENUM_NULL,
-                                "number of search passes on the messsage receive queue",
-                                MPIX_T_BIND_NO_OBJECT,
+                                MPI_T_ENUM_NULL,
+                                "number of search passes on the message receive queue",
+                                MPI_T_BIND_NO_OBJECT,
                                 /*readonly=*/FALSE,
                                 /*continuous=*/TRUE,
                                 /*atomic=*/FALSE,
@@ -213,6 +183,58 @@ int MPIDI_CH3U_Recvq_init(void)
                                 &simple_aint_creator,
                                 &idx);
     if (mpi_errno) MPIU_ERR_POP(mpi_errno);
+
+    /* time spent unsuccessfully trying to match incoming message with posted receives */
+    mpi_errno = MPIR_T_pvar_add("time_failed_matching_postedq",
+                                MPI_T_VERBOSITY_USER_DETAIL,
+                                MPI_T_PVAR_CLASS_TIMER,
+                                MPI_DOUBLE,
+                                MPI_T_ENUM_NULL,
+                                "total time spent on unsuccessful search passes on the posted receives queue",
+                                MPI_T_BIND_NO_OBJECT,
+                                /*readonly=*/FALSE,
+                                /*continuous=*/TRUE,
+                                /*atomic=*/FALSE,
+                                MPIR_T_PVAR_IMPL_SIMPLE,
+                                /*var_state=*/&time_failed_matching_postedq,
+                                &simple_double_creator,
+                                &idx);
+    if (mpi_errno) MPIU_ERR_POP(mpi_errno);
+
+    /* time spent trying to match a posted receive with messages in the unexpected queue */
+    mpi_errno = MPIR_T_pvar_add("time_matching_unexpectedq",
+                                MPI_T_VERBOSITY_USER_DETAIL,
+                                MPI_T_PVAR_CLASS_TIMER,
+                                MPI_DOUBLE,
+                                MPI_T_ENUM_NULL,
+                                "total time spent on search passes on the unexpected receive queue",
+                                MPI_T_BIND_NO_OBJECT,
+                                /*readonly=*/FALSE,
+                                /*continuous=*/TRUE,
+                                /*atomic=*/FALSE,
+                                MPIR_T_PVAR_IMPL_SIMPLE,
+                                /*var_state=*/&time_matching_unexpectedq,
+                                &simple_double_creator,
+                                &idx);
+    if (mpi_errno) MPIU_ERR_POP(mpi_errno);
+
+    /* allocated buffer size in the unexpected receive queue */
+    mpi_errno = MPIR_T_pvar_add("unexpected_recvq_buffer_size",
+                                MPI_T_VERBOSITY_USER_DETAIL,
+                                MPI_T_PVAR_CLASS_LEVEL,
+                                MPI_AINT,
+                                MPI_T_ENUM_NULL,
+                                "total buffer size allocated in the unexpected receive queue",
+                                MPI_T_BIND_NO_OBJECT,
+                                /*readonly=*/TRUE,
+                                /*continuous=*/TRUE,
+                                /*atomic=*/FALSE,
+                                MPIR_T_PVAR_IMPL_SIMPLE,
+                                /*var_state=*/&MPIDI_CH3I_unexpected_recvq_buffer_size,
+                                &simple_aint_creator,
+                                &idx);
+    if (mpi_errno) MPIU_ERR_POP(mpi_errno);
+
 #endif
 fn_fail:
     return mpi_errno;
@@ -224,7 +246,7 @@ fn_fail:
  * MPIDI_CH3U_Recvq_FU()
  *
  * Search for a matching request in the unexpected receive queue.  Return 
- * true if one is found, false otherwise.  If the status arguement is
+ * true if one is found, false otherwise.  If the status argument is
  * not MPI_STATUS_IGNORE, return information about the request in that
  * parameter.  This routine is used by mpid_probe and mpid_iprobe.
  *
@@ -246,6 +268,7 @@ fn_fail:
 int MPIDI_CH3U_Recvq_FU(int source, int tag, int context_id, MPI_Status *s)
 {
     MPID_Request * rreq;
+    MPID_Time_t timer_start;
     int found = 0;
     MPIDI_Message_match match, mask;
     MPIDI_STATE_DECL(MPID_STATE_MPIDI_CH3U_RECVQ_FU);
@@ -261,12 +284,14 @@ int MPIDI_CH3U_Recvq_FU(int source, int tag, int context_id, MPI_Status *s)
     match.parts.rank = source;
 
     if (tag != MPI_ANY_TAG && source != MPI_ANY_SOURCE) {
+        MPIR_T_START_TIMER(RECVQ_STATISTICS, timer_start);
 	while (rreq != NULL) {
-            MPIR_T_INC(unexpected_recvq_match_attempts);
+            MPIR_T_INC(RECVQ_STATISTICS, unexpected_recvq_match_attempts);
 	    if (MATCH_WITH_NO_MASK(rreq->dev.match, match))
 		break;
 	    rreq = rreq->dev.next;
 	}
+        MPIR_T_END_TIMER(RECVQ_STATISTICS, timer_start, time_matching_unexpectedq);
     }
     else {
 	mask.parts.context_id = mask.parts.rank = mask.parts.tag = ~0;
@@ -275,12 +300,14 @@ int MPIDI_CH3U_Recvq_FU(int source, int tag, int context_id, MPI_Status *s)
 	if (source == MPI_ANY_SOURCE)
 	    match.parts.rank = mask.parts.rank = 0;
 
+        MPIR_T_START_TIMER(RECVQ_STATISTICS, timer_start);
 	while (rreq != NULL) {
-            MPIR_T_INC(unexpected_recvq_match_attempts);
+            MPIR_T_INC(RECVQ_STATISTICS, unexpected_recvq_match_attempts);
 	    if (MATCH_WITH_LEFT_MASK(rreq->dev.match, match, mask))
 		break;
 	    rreq = rreq->dev.next;
 	}
+        MPIR_T_END_TIMER(RECVQ_STATISTICS, timer_start, time_matching_unexpectedq);
     }
 
     /* Save the information about the request before releasing the 
@@ -319,6 +346,7 @@ int MPIDI_CH3U_Recvq_FU(int source, int tag, int context_id, MPI_Status *s)
 MPID_Request * MPIDI_CH3U_Recvq_FDU(MPI_Request sreq_id, 
 				    MPIDI_Message_match * match)
 {
+    MPID_Time_t timer_start;
     MPID_Request * rreq;
     MPID_Request * prev_rreq;
     MPID_Request * cur_rreq;
@@ -339,12 +367,18 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU(MPI_Request sreq_id,
     /* FIXME: Why doesn't this exit after it finds the first match? */
     cur_rreq = recvq_unexpected_head;
     while (cur_rreq != NULL) {
-	if (cur_rreq->dev.sender_req_id == sreq_id &&
-            MPIR_T_INC(unexpected_recvq_match_attempts) &&
-	    (MATCH_WITH_NO_MASK(cur_rreq->dev.match, *match))) {
-	    matching_prev_rreq = prev_rreq;
-	    matching_cur_rreq = cur_rreq;
+        MPIR_T_START_TIMER(RECVQ_STATISTICS, timer_start);
+
+        if (cur_rreq->dev.sender_req_id == sreq_id) {
+            MPIR_T_INC(RECVQ_STATISTICS, unexpected_recvq_match_attempts);
+
+            if (MATCH_WITH_NO_MASK(cur_rreq->dev.match, *match)) {
+                matching_prev_rreq = prev_rreq;
+                matching_cur_rreq = cur_rreq;
+            }
 	}
+        MPIR_T_END_TIMER(RECVQ_STATISTICS, timer_start, time_matching_unexpectedq);
+
 	prev_rreq = cur_rreq;
 	cur_rreq = cur_rreq->dev.next;
     }
@@ -361,8 +395,10 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU(MPI_Request sreq_id,
 	    recvq_unexpected_tail = matching_prev_rreq;
 	}
 
-        MPIR_T_DEC(unexpected_qlen);
+        MPIR_T_DEC(RECVQ_STATISTICS, unexpected_qlen);
 	rreq = matching_cur_rreq;
+
+        MPIR_T_SUBTRACT(RECVQ_STATISTICS, MPIDI_CH3I_unexpected_recvq_buffer_size, rreq->dev.tmpbuf_sz);
     }
     else {
 	rreq = NULL;
@@ -382,6 +418,7 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU(MPI_Request sreq_id,
 #define FCNAME MPIDI_QUOTE(FUNCNAME)
 MPID_Request * MPIDI_CH3U_Recvq_FDU_matchonly(int source, int tag, int context_id, MPID_Comm *comm, int *foundp)
 {
+    MPID_Time_t timer_start;
     int found = FALSE;
     MPID_Request *rreq, *prev_rreq;
     MPIDI_Message_match match;
@@ -392,6 +429,9 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_matchonly(int source, int tag, int context_i
 
     MPIU_THREAD_CS_ASSERT_HELD(MSGQUEUE);
 
+    /* Store how much time is spent traversing the queue */
+    MPIR_T_START_TIMER(RECVQ_STATISTICS, timer_start);
+
     /* Optimize this loop for an empty unexpected receive queue */
     rreq = recvq_unexpected_head;
     if (rreq) {
@@ -403,7 +443,7 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_matchonly(int source, int tag, int context_i
 
         if (tag != MPI_ANY_TAG && source != MPI_ANY_SOURCE) {
             do {
-                MPIR_T_INC(unexpected_recvq_match_attempts);
+                MPIR_T_INC(RECVQ_STATISTICS, unexpected_recvq_match_attempts);
                 if (MATCH_WITH_NO_MASK(rreq->dev.match, match)) {
                     if (prev_rreq != NULL) {
                         prev_rreq->dev.next = rreq->dev.next;
@@ -415,7 +455,8 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_matchonly(int source, int tag, int context_i
                     if (rreq->dev.next == NULL) {
                         recvq_unexpected_tail = prev_rreq;
                     }
-                    MPIR_T_DEC(unexpected_qlen);
+                    MPIR_T_DEC(RECVQ_STATISTICS, unexpected_qlen);
+                    MPIR_T_SUBTRACT(RECVQ_STATISTICS, MPIDI_CH3I_unexpected_recvq_buffer_size, rreq->dev.tmpbuf_sz);
 
                     rreq->comm = comm;
                     MPIR_Comm_add_ref(comm);
@@ -436,7 +477,7 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_matchonly(int source, int tag, int context_i
                 match.parts.rank = mask.parts.rank = 0;
 
             do {
-                MPIR_T_INC(unexpected_recvq_match_attempts);
+                MPIR_T_INC(RECVQ_STATISTICS, unexpected_recvq_match_attempts);
                 if (MATCH_WITH_LEFT_MASK(rreq->dev.match, match, mask)) {
                     if (prev_rreq != NULL) {
                         prev_rreq->dev.next = rreq->dev.next;
@@ -447,7 +488,8 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_matchonly(int source, int tag, int context_i
                     if (rreq->dev.next == NULL) {
                         recvq_unexpected_tail = prev_rreq;
                     }
-                    MPIR_T_DEC(unexpected_qlen);
+                    MPIR_T_DEC(RECVQ_STATISTICS, unexpected_qlen);
+                    MPIR_T_SUBTRACT(RECVQ_STATISTICS, MPIDI_CH3I_unexpected_recvq_buffer_size, rreq->dev.tmpbuf_sz);
 
                     rreq->comm                 = comm;
                     MPIR_Comm_add_ref(comm);
@@ -463,6 +505,8 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_matchonly(int source, int tag, int context_i
     }
 
 lock_exit:
+    MPIR_T_END_TIMER(RECVQ_STATISTICS, timer_start, time_matching_unexpectedq);
+
     *foundp = found;
 
     MPIDI_FUNC_EXIT(MPID_STATE_MPIDI_CH3U_RECVQ_FDU_MATCHONLY);
@@ -491,6 +535,7 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_or_AEP(int source, int tag,
                                            int context_id, MPID_Comm *comm, void *user_buf,
                                            int user_count, MPI_Datatype datatype, int * foundp)
 {
+    MPID_Time_t timer_start;
     int found;
     MPID_Request *rreq, *prev_rreq;
     MPIDI_Message_match match;
@@ -501,6 +546,9 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_or_AEP(int source, int tag,
 
     MPIU_THREAD_CS_ASSERT_HELD(MSGQUEUE);
 
+    /* Store how much time is spent traversing the queue */
+    MPIR_T_START_TIMER(RECVQ_STATISTICS, timer_start);
+
     /* Optimize this loop for an empty unexpected receive queue */
     rreq = recvq_unexpected_head;
     if (rreq) {
@@ -512,7 +560,7 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_or_AEP(int source, int tag,
 
 	if (tag != MPI_ANY_TAG && source != MPI_ANY_SOURCE) {
 	    do {
-                MPIR_T_INC(unexpected_recvq_match_attempts);
+                MPIR_T_INC(RECVQ_STATISTICS, unexpected_recvq_match_attempts);
 		if (MATCH_WITH_NO_MASK(rreq->dev.match, match)) {
 		    if (prev_rreq != NULL) {
 			prev_rreq->dev.next = rreq->dev.next;
@@ -524,7 +572,10 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_or_AEP(int source, int tag,
 		    if (rreq->dev.next == NULL) {
 			recvq_unexpected_tail = prev_rreq;
 		    }
-                    MPIR_T_DEC(unexpected_qlen);
+                    MPIR_T_DEC(RECVQ_STATISTICS, unexpected_qlen);
+
+                    if (MPIDI_Request_get_msg_type(rreq) == MPIDI_REQUEST_EAGER_MSG)
+                        MPIR_T_SUBTRACT(RECVQ_STATISTICS, MPIDI_CH3I_unexpected_recvq_buffer_size, rreq->dev.tmpbuf_sz);
 
 		    rreq->comm = comm;
 		    MPIR_Comm_add_ref(comm);
@@ -546,7 +597,7 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_or_AEP(int source, int tag,
 		match.parts.rank = mask.parts.rank = 0;
 
 	    do {
-                MPIR_T_INC(unexpected_recvq_match_attempts);
+                MPIR_T_INC(RECVQ_STATISTICS, unexpected_recvq_match_attempts);
 		if (MATCH_WITH_LEFT_MASK(rreq->dev.match, match, mask)) {
 		    if (prev_rreq != NULL) {
 			prev_rreq->dev.next = rreq->dev.next;
@@ -557,7 +608,10 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_or_AEP(int source, int tag,
 		    if (rreq->dev.next == NULL) {
 			recvq_unexpected_tail = prev_rreq;
 		    }
-                    MPIR_T_DEC(unexpected_qlen);
+                    MPIR_T_DEC(RECVQ_STATISTICS, unexpected_qlen);
+
+                    if (MPIDI_Request_get_msg_type(rreq) == MPIDI_REQUEST_EAGER_MSG)
+                        MPIR_T_SUBTRACT(RECVQ_STATISTICS, MPIDI_CH3I_unexpected_recvq_buffer_size, rreq->dev.tmpbuf_sz);
 
 		    rreq->comm                 = comm;
 		    MPIR_Comm_add_ref(comm);
@@ -572,7 +626,8 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_or_AEP(int source, int tag,
 	    } while (rreq);
 	}
     }
-    
+    MPIR_T_END_TIMER(RECVQ_STATISTICS, timer_start, time_matching_unexpectedq);
+
     /* A matching request was not found in the unexpected queue, so we 
        need to allocate a new request and add it to the posted queue */
     {
@@ -629,13 +684,16 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_or_AEP(int source, int tag,
 	    recvq_posted_head = rreq;
 	}
 	recvq_posted_tail = rreq;
-        MPIR_T_INC(posted_qlen);
+        MPIR_T_INC(RECVQ_STATISTICS, posted_qlen);
 	MPIDI_POSTED_RECV_ENQUEUE_HOOK(rreq);
     }
     
   lock_exit:
-
     *foundp = found;
+
+    /* If a match was not found, the timer was stopped after the traversal */
+    if (found)
+        MPIR_T_END_TIMER(RECVQ_STATISTICS, timer_start, time_matching_unexpectedq);
     
     MPIDI_FUNC_EXIT(MPID_STATE_MPIDI_CH3U_RECVQ_FDU_OR_AEP);
     return rreq;
@@ -657,6 +715,7 @@ MPID_Request * MPIDI_CH3U_Recvq_FDU_or_AEP(int source, int tag,
 int MPIDI_CH3U_Recvq_DP(MPID_Request * rreq)
 {
     int found;
+    MPID_Time_t timer_start;
     MPID_Request * cur_rreq;
     MPID_Request * prev_rreq;
     int dequeue_failed;
@@ -669,6 +728,7 @@ int MPIDI_CH3U_Recvq_DP(MPID_Request * rreq)
 
     /* MT FIXME is this right? or should the caller do this? */
     MPIU_THREAD_CS_ENTER(MSGQUEUE,);
+    MPIR_T_START_TIMER(RECVQ_STATISTICS, timer_start);
     cur_rreq = recvq_posted_head;
     while (cur_rreq != NULL) {
 	if (cur_rreq == rreq) {
@@ -681,7 +741,7 @@ int MPIDI_CH3U_Recvq_DP(MPID_Request * rreq)
 	    if (cur_rreq->dev.next == NULL) {
 		recvq_posted_tail = prev_rreq;
 	    }
-            MPIR_T_DEC(posted_qlen);
+            MPIR_T_DEC(RECVQ_STATISTICS, posted_qlen);
             /* Notify channel that rreq has been dequeued and check if
                it has already matched rreq, fail if so */
 	    dequeue_failed = MPIDI_POSTED_RECV_DEQUEUE_HOOK(rreq);
@@ -693,6 +753,8 @@ int MPIDI_CH3U_Recvq_DP(MPID_Request * rreq)
 	prev_rreq = cur_rreq;
 	cur_rreq = cur_rreq->dev.next;
     }
+    if (!found)
+        MPIR_T_END_TIMER(RECVQ_STATISTICS, timer_start, time_failed_matching_postedq);
 
     MPIU_THREAD_CS_EXIT(MSGQUEUE,);
 
@@ -726,6 +788,7 @@ int MPIDI_CH3U_Recvq_DP(MPID_Request * rreq)
 MPID_Request * MPIDI_CH3U_Recvq_FDP_or_AEU(MPIDI_Message_match * match, 
 					   int * foundp)
 {
+    MPID_Time_t timer_start;
     int found;
     MPID_Request * rreq;
     MPID_Request * prev_rreq;
@@ -741,8 +804,9 @@ MPID_Request * MPIDI_CH3U_Recvq_FDP_or_AEU(MPIDI_Message_match * match,
 
     rreq = recvq_posted_head;
 
+    MPIR_T_START_TIMER(RECVQ_STATISTICS, timer_start);
     while (rreq != NULL) {
-        MPIR_T_INC(posted_recvq_match_attempts);
+        MPIR_T_INC(RECVQ_STATISTICS, posted_recvq_match_attempts);
 	if (MATCH_WITH_LEFT_RIGHT_MASK(rreq->dev.match, *match, rreq->dev.mask)) {
 	    if (prev_rreq != NULL) {
 		prev_rreq->dev.next = rreq->dev.next;
@@ -753,7 +817,7 @@ MPID_Request * MPIDI_CH3U_Recvq_FDP_or_AEU(MPIDI_Message_match * match,
 	    if (rreq->dev.next == NULL) {
 		recvq_posted_tail = prev_rreq;
 	    }
-            MPIR_T_DEC(posted_qlen);
+            MPIR_T_DEC(RECVQ_STATISTICS, posted_qlen);
 
             /* give channel a chance to match the request, try again if so */
 	    channel_matched = MPIDI_POSTED_RECV_DEQUEUE_HOOK(rreq);
@@ -766,6 +830,7 @@ MPID_Request * MPIDI_CH3U_Recvq_FDP_or_AEU(MPIDI_Message_match * match,
 	prev_rreq = rreq;
 	rreq = rreq->dev.next;
     }
+    MPIR_T_END_TIMER(RECVQ_STATISTICS, timer_start, time_failed_matching_postedq);
 
     /* A matching request was not found in the posted queue, so we 
        need to allocate a new request and add it to the unexpected queue */
@@ -784,7 +849,7 @@ MPID_Request * MPIDI_CH3U_Recvq_FDP_or_AEU(MPIDI_Message_match * match,
 	    recvq_unexpected_head = rreq;
 	}
 	recvq_unexpected_tail = rreq;
-        MPIR_T_INC(unexpected_qlen);
+        MPIR_T_INC(RECVQ_STATISTICS, unexpected_qlen);
     }
     
     found = FALSE;
@@ -831,7 +896,7 @@ static inline void dequeue_and_set_error(MPID_Request **req,  MPID_Request *prev
     if (recvq_posted_tail == *req)
         recvq_posted_tail = prev_req;
 
-    MPIR_T_DEC(posted_qlen);
+    MPIR_T_DEC(RECVQ_STATISTICS, posted_qlen);
 
     /* set error and complete */
     (*req)->status.MPI_ERROR = *error;
@@ -942,7 +1007,9 @@ static char *rank_val_to_str(int rank, char *out, int max)
     }
     return out;
 }
+/* --END ERROR HANDLING-- */
 
+/* --BEGIN DEBUG-- */
 /* satisfy the compiler */
 void MPIDI_CH3U_Dbg_print_recvq(FILE *stream);
 
@@ -999,7 +1066,7 @@ void MPIDI_CH3U_Dbg_print_recvq(FILE *stream)
     }
     fprintf(stream, "========================================\n");
 }
-/* --END ERROR HANDLING-- */
+/* --END DEBUG-- */
 
 /* returns the number of elements in the unexpected queue */
 #undef FUNCNAME
