@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -109,7 +109,8 @@ int MPID_Finalize(void)
 #if 1
     /* FIXME: The close actions should use the same code as the other
        connection close code */
-    MPIDI_PG_Close_VCs();
+    mpi_errno = MPIDI_PG_Close_VCs();
+    if (mpi_errno) MPIU_ERR_POP(mpi_errno);
     /*
      * Wait for all VCs to finish the close protocol
      */
