@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -27,6 +27,7 @@ int MPID_Ssend(const void * buf, int count, MPI_Datatype datatype, int rank, int
 #if defined(MPID_USE_SEQUENCE_NUMBERS)
     MPID_Seqnum_t seqnum;
 #endif    
+    int eager_threshold = -1;
     int mpi_errno = MPI_SUCCESS;
     MPIDI_STATE_DECL(MPID_STATE_MPID_SSEND);
 
@@ -86,8 +87,10 @@ int MPID_Ssend(const void * buf, int count, MPI_Datatype datatype, int rank, int
 					     context_offset );
 	goto fn_exit;
     }
-    
-    if (data_sz + sizeof(MPIDI_CH3_Pkt_eager_sync_send_t) <= vc->eager_max_msg_sz)
+
+    MPIDI_CH3_GET_EAGER_THRESHOLD(&eager_threshold, comm, vc);
+
+    if (data_sz + sizeof(MPIDI_CH3_Pkt_eager_sync_send_t) <= eager_threshold)
     {
 	mpi_errno = MPIDI_CH3_EagerSyncNoncontigSend( &sreq, buf, count,
                                                       datatype, data_sz, 
