@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -721,8 +721,8 @@ int MPIDI_VC_Init( MPIDI_VC_t *vc, MPIDI_PG_t *pg, int rank )
     MPIDI_VC_Init_seqnum_recv(vc);
     vc->rndvSend_fn      = MPIDI_CH3_RndvSend;
     vc->rndvRecv_fn      = MPIDI_CH3_RecvRndv;
-    vc->eager_max_msg_sz = MPIDI_CH3_EAGER_MAX_MSG_SIZE;
     vc->ready_eager_max_msg_sz = -1; /* no limit */;
+    vc->eager_max_msg_sz = MPIR_PARAM_CH3_EAGER_MAX_MSG_SIZE;
 
     vc->sendNoncontig_fn = MPIDI_CH3_SendNoncontig_iov;
 #ifdef ENABLE_COMM_OVERRIDES
