@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -54,7 +54,7 @@
 #error This code assumes that __BYTE_ORDER and __BIG_ENDIAN are defined
 #endif
 /* FIXME: "BLENDIAN" is a non-conforming name - it could conflict with some
-   other definition in a non-mpich2 header file */
+   other definition in a non-mpich header file */
 #if ((defined(_BIG_ENDIAN) && !defined(ntohl)) || (__BYTE_ORDER == __BIG_ENDIAN))
 #define BLENDIAN 0 /* detected host arch byte order is big endian */
 #else
@@ -62,13 +62,6 @@
 #endif
 #endif
 
-#if 0
-#if !defined(__FLOAT_WORD_ORDER) || !defined(__LITTLE_ENDIAN)
-#error This code assumes that __FLOAT_WORD_ORDER and __LITTLE_ENDIAN are defined
-#endif
-#define FLENDIAN (__FLOAT_WORD_ORDER == __LITTLE_ENDIAN)
-#endif
-
 /*
   set to 1: uses manual swapping routines
             for 16/32 bit data types
