@@ -16,13 +16,20 @@
 
 pthread_mutex_t *OPA_emulation_lock = NULL;
 
-int OPA_Interprocess_lock_init(pthread_mutex_t *shm_lock, int isLeader)
+int OPA_Interprocess_lock_init(OPA_emulation_ipl_t *shm_lock, int isLeader)
 {
     int mpi_errno = 0; /*MPI_SUCCESS*/
+    pthread_mutexattr_t attr;
     OPA_emulation_lock = shm_lock;
 
     if (isLeader) {
-        pthread_mutex_init(OPA_emulation_lock, NULL);
+        /* Set the mutex attributes to work correctly on inter-process
+         * shared memory as well. This is required for some compilers
+         * (such as SUN Studio) that don't enable it by default. */
+        if (pthread_mutexattr_init(&attr) ||
+            pthread_mutexattr_setpshared(&attr, PTHREAD_PROCESS_SHARED) ||
+            pthread_mutex_init(OPA_emulation_lock, &attr))
+            mpi_errno = 16; /* MPI_ERR_INTERN */
     }
 
     return mpi_errno;
