@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -22,7 +22,7 @@ extern int snprintf(char *, size_t, const char *, ...) ATTRIBUTE((format(printf,
 #if defined MPL_HAVE_SNPRINTF
 #define MPL_snprintf snprintf
 #else
-int MPL_snprintf(char *, size_t, const char *, ...);
+int MPL_snprintf(char *, size_t, const char *, ...) ATTRIBUTE((format(printf,3,4)));
 #endif /* MPL_HAVE_SNPRINTF */
 
 #if defined MPL_NEEDS_STRDUP_DECL && !defined strdup
