@@ -1,6 +1,6 @@
 /*
  * Copyright © 2009      CNRS
- * Copyright © 2009-2011 inria.  All rights reserved.
+ * Copyright © 2009-2012 Inria.  All rights reserved.
  * Copyright © 2009-2012 Université Bordeaux 1
  * Copyright © 2009-2011 Cisco Systems, Inc.  All rights reserved.
  *
@@ -15,8 +15,12 @@
 #include <private/autogen/config.h>
 #include <hwloc.h>
 #include <hwloc/bitmap.h>
+#include <private/components.h>
 #include <private/debug.h>
 #include <sys/types.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 #ifdef HAVE_STDINT_H
 #include <stdint.h>
 #endif
@@ -47,21 +51,6 @@ enum hwloc_ignore_type_e {
 
 #define HWLOC_DEPTH_MAX 128
 
-typedef enum hwloc_backend_e {
-  HWLOC_BACKEND_NONE,
-  HWLOC_BACKEND_SYNTHETIC,
-#ifdef HWLOC_LINUX_SYS
-  HWLOC_BACKEND_LINUXFS,
-#endif
-  HWLOC_BACKEND_XML,
-  HWLOC_BACKEND_CUSTOM,
-  /* This value is only here so that we can end the enum list without
-     a comma (thereby preventing compiler warnings) */
-  HWLOC_BACKEND_MAX
-} hwloc_backend_t;
-
-struct hwloc__xml_import_state_s;
-
 struct hwloc_topology {
   unsigned nb_levels;					/* Number of horizontal levels */
   unsigned next_group_depth;				/* Depth of the next Group object that we may create */
@@ -84,38 +73,43 @@ struct hwloc_topology {
   struct hwloc_obj **osdev_level;
   struct hwloc_obj *first_osdev, *last_osdev;
 
-  int (*set_thisproc_cpubind)(hwloc_topology_t topology, hwloc_const_cpuset_t set, int flags);
-  int (*get_thisproc_cpubind)(hwloc_topology_t topology, hwloc_cpuset_t set, int flags);
-  int (*set_thisthread_cpubind)(hwloc_topology_t topology, hwloc_const_cpuset_t set, int flags);
-  int (*get_thisthread_cpubind)(hwloc_topology_t topology, hwloc_cpuset_t set, int flags);
-  int (*set_proc_cpubind)(hwloc_topology_t topology, hwloc_pid_t pid, hwloc_const_cpuset_t set, int flags);
-  int (*get_proc_cpubind)(hwloc_topology_t topology, hwloc_pid_t pid, hwloc_cpuset_t set, int flags);
+  struct hwloc_binding_hooks {
+    int (*set_thisproc_cpubind)(hwloc_topology_t topology, hwloc_const_cpuset_t set, int flags);
+    int (*get_thisproc_cpubind)(hwloc_topology_t topology, hwloc_cpuset_t set, int flags);
+    int (*set_thisthread_cpubind)(hwloc_topology_t topology, hwloc_const_cpuset_t set, int flags);
+    int (*get_thisthread_cpubind)(hwloc_topology_t topology, hwloc_cpuset_t set, int flags);
+    int (*set_proc_cpubind)(hwloc_topology_t topology, hwloc_pid_t pid, hwloc_const_cpuset_t set, int flags);
+    int (*get_proc_cpubind)(hwloc_topology_t topology, hwloc_pid_t pid, hwloc_cpuset_t set, int flags);
 #ifdef hwloc_thread_t
-  int (*set_thread_cpubind)(hwloc_topology_t topology, hwloc_thread_t tid, hwloc_const_cpuset_t set, int flags);
-  int (*get_thread_cpubind)(hwloc_topology_t topology, hwloc_thread_t tid, hwloc_cpuset_t set, int flags);
+    int (*set_thread_cpubind)(hwloc_topology_t topology, hwloc_thread_t tid, hwloc_const_cpuset_t set, int flags);
+    int (*get_thread_cpubind)(hwloc_topology_t topology, hwloc_thread_t tid, hwloc_cpuset_t set, int flags);
 #endif
 
-  int (*get_thisproc_last_cpu_location)(hwloc_topology_t topology, hwloc_cpuset_t set, int flags);
-  int (*get_thisthread_last_cpu_location)(hwloc_topology_t topology, hwloc_cpuset_t set, int flags);
-  int (*get_proc_last_cpu_location)(hwloc_topology_t topology, hwloc_pid_t pid, hwloc_cpuset_t set, int flags);
+    int (*get_thisproc_last_cpu_location)(hwloc_topology_t topology, hwloc_cpuset_t set, int flags);
+    int (*get_thisthread_last_cpu_location)(hwloc_topology_t topology, hwloc_cpuset_t set, int flags);
+    int (*get_proc_last_cpu_location)(hwloc_topology_t topology, hwloc_pid_t pid, hwloc_cpuset_t set, int flags);
 
-  int (*set_thisproc_membind)(hwloc_topology_t topology, hwloc_const_nodeset_t nodeset, hwloc_membind_policy_t policy, int flags);
-  int (*get_thisproc_membind)(hwloc_topology_t topology, hwloc_nodeset_t nodeset, hwloc_membind_policy_t * policy, int flags);
-  int (*set_thisthread_membind)(hwloc_topology_t topology, hwloc_const_nodeset_t nodeset, hwloc_membind_policy_t policy, int flags);
-  int (*get_thisthread_membind)(hwloc_topology_t topology, hwloc_nodeset_t nodeset, hwloc_membind_policy_t * policy, int flags);
-  int (*set_proc_membind)(hwloc_topology_t topology, hwloc_pid_t pid, hwloc_const_nodeset_t nodeset, hwloc_membind_policy_t policy, int flags);
-  int (*get_proc_membind)(hwloc_topology_t topology, hwloc_pid_t pid, hwloc_nodeset_t nodeset, hwloc_membind_policy_t * policy, int flags);
-  int (*set_area_membind)(hwloc_topology_t topology, const void *addr, size_t len, hwloc_const_nodeset_t nodeset, hwloc_membind_policy_t policy, int flags);
-  int (*get_area_membind)(hwloc_topology_t topology, const void *addr, size_t len, hwloc_nodeset_t nodeset, hwloc_membind_policy_t * policy, int flags);
-  /* This has to return the same kind of pointer as alloc_membind, so that free_membind can be used on it */
-  void *(*alloc)(hwloc_topology_t topology, size_t len);
-  /* alloc_membind has to always succeed if !(flags & HWLOC_MEMBIND_STRICT).
-   * see hwloc_alloc_or_fail which is convenient for that.  */
-  void *(*alloc_membind)(hwloc_topology_t topology, size_t len, hwloc_const_nodeset_t nodeset, hwloc_membind_policy_t policy, int flags);
-  int (*free_membind)(hwloc_topology_t topology, void *addr, size_t len);
+    int (*set_thisproc_membind)(hwloc_topology_t topology, hwloc_const_nodeset_t nodeset, hwloc_membind_policy_t policy, int flags);
+    int (*get_thisproc_membind)(hwloc_topology_t topology, hwloc_nodeset_t nodeset, hwloc_membind_policy_t * policy, int flags);
+    int (*set_thisthread_membind)(hwloc_topology_t topology, hwloc_const_nodeset_t nodeset, hwloc_membind_policy_t policy, int flags);
+    int (*get_thisthread_membind)(hwloc_topology_t topology, hwloc_nodeset_t nodeset, hwloc_membind_policy_t * policy, int flags);
+    int (*set_proc_membind)(hwloc_topology_t topology, hwloc_pid_t pid, hwloc_const_nodeset_t nodeset, hwloc_membind_policy_t policy, int flags);
+    int (*get_proc_membind)(hwloc_topology_t topology, hwloc_pid_t pid, hwloc_nodeset_t nodeset, hwloc_membind_policy_t * policy, int flags);
+    int (*set_area_membind)(hwloc_topology_t topology, const void *addr, size_t len, hwloc_const_nodeset_t nodeset, hwloc_membind_policy_t policy, int flags);
+    int (*get_area_membind)(hwloc_topology_t topology, const void *addr, size_t len, hwloc_nodeset_t nodeset, hwloc_membind_policy_t * policy, int flags);
+    /* This has to return the same kind of pointer as alloc_membind, so that free_membind can be used on it */
+    void *(*alloc)(hwloc_topology_t topology, size_t len);
+    /* alloc_membind has to always succeed if !(flags & HWLOC_MEMBIND_STRICT).
+     * see hwloc_alloc_or_fail which is convenient for that.  */
+    void *(*alloc_membind)(hwloc_topology_t topology, size_t len, hwloc_const_nodeset_t nodeset, hwloc_membind_policy_t policy, int flags);
+    int (*free_membind)(hwloc_topology_t topology, void *addr, size_t len);
+  } binding_hooks;
 
   struct hwloc_topology_support support;
 
+  void (*userdata_export_cb)(void *reserved, struct hwloc_topology *topology, struct hwloc_obj *obj);
+  void (*userdata_import_cb)(struct hwloc_topology *topology, struct hwloc_obj *obj, const char *name, const void *buffer, size_t length);
+
   struct hwloc_os_distances_s {
     hwloc_obj_type_t type;
     int nbobjs;
@@ -134,46 +128,11 @@ struct hwloc_topology {
     struct hwloc_os_distances_s *prev, *next;
   } *first_osdist, *last_osdist;
 
-  hwloc_backend_t backend_type;
-  union hwloc_backend_params_u {
-#ifdef HWLOC_LINUX_SYS
-    struct hwloc_backend_params_linuxfs_s {
-      /* FS root parameters */
-      char *root_path; /* The path of the file system root, used when browsing, e.g., Linux' sysfs and procfs. */
-      int root_fd; /* The file descriptor for the file system root, used when browsing, e.g., Linux' sysfs and procfs. */
-      struct utsname utsname; /* cached result of uname, used multiple times */
-    } linuxfs;
-#endif /* HWLOC_LINUX_SYS */
-#if defined(HWLOC_OSF_SYS) || defined(HWLOC_COMPILE_PORTS)
-    struct hwloc_backend_params_osf {
-      int nbnodes;
-    } osf;
-#endif /* HWLOC_OSF_SYS */
-    struct hwloc_backend_params_xml_s {
-      /* xml backend parameters */
-      int (*look)(struct hwloc_topology *topology, struct hwloc__xml_import_state_s *state);
-      void (*look_failed)(struct hwloc_topology *topology);
-      void (*backend_exit)(struct hwloc_topology *topology);
-      void *data; /* libxml2 doc, or nolibxml buffer */
-      struct hwloc_xml_imported_distances_s {
-	hwloc_obj_t root;
-	struct hwloc_distances_s distances;
-	struct hwloc_xml_imported_distances_s *prev, *next;
-      } *first_distances, *last_distances;
-    } xml;
-    struct hwloc_backend_params_synthetic_s {
-      /* synthetic backend parameters */
-      char *string;
-#define HWLOC_SYNTHETIC_MAX_DEPTH 128
-      unsigned arity[HWLOC_SYNTHETIC_MAX_DEPTH];
-      hwloc_obj_type_t type[HWLOC_SYNTHETIC_MAX_DEPTH];
-      unsigned id[HWLOC_SYNTHETIC_MAX_DEPTH];
-      unsigned depth[HWLOC_SYNTHETIC_MAX_DEPTH]; /* For cache/misc */
-    } synthetic;
-  } backend_params;
+  /* list of enabled backends. */
+  struct hwloc_backend * backends;
 };
 
-
+extern void hwloc_alloc_obj_cpusets(hwloc_obj_t obj);
 extern void hwloc_setup_pu_level(struct hwloc_topology *topology, unsigned nb_pus);
 extern int hwloc_get_sysctlbyname(const char *name, int64_t *n);
 extern int hwloc_get_sysctl(int name[], unsigned namelen, int *n);
@@ -181,65 +140,46 @@ extern unsigned hwloc_fallback_nbprocessors(struct hwloc_topology *topology);
 extern void hwloc_connect_children(hwloc_obj_t obj);
 extern int hwloc_connect_levels(hwloc_topology_t topology);
 
+extern void hwloc_topology_setup_defaults(struct hwloc_topology *topology);
+extern void hwloc_topology_clear(struct hwloc_topology *topology);
+
+/* set native OS binding hooks */
+extern void hwloc_set_native_binding_hooks(struct hwloc_binding_hooks *hooks, struct hwloc_topology_support *support);
+/* set either native OS binding hooks (if thissystem), or dummy ones */
+extern void hwloc_set_binding_hooks(struct hwloc_topology *topology);
 
 #if defined(HWLOC_LINUX_SYS)
-extern void hwloc_look_linuxfs(struct hwloc_topology *topology);
-extern void hwloc_set_linuxfs_hooks(struct hwloc_topology *topology);
-extern int hwloc_backend_linuxfs_init(struct hwloc_topology *topology, const char *fsroot_path);
-extern void hwloc_backend_linuxfs_exit(struct hwloc_topology *topology);
-extern void hwloc_linuxfs_pci_lookup_osdevices(struct hwloc_topology *topology, struct hwloc_obj *pcidev);
-extern int hwloc_linuxfs_get_pcidev_cpuset(struct hwloc_topology *topology, struct hwloc_obj *pcidev, hwloc_bitmap_t cpuset);
+extern void hwloc_set_linuxfs_hooks(struct hwloc_binding_hooks *binding_hooks, struct hwloc_topology_support *support);
 #endif /* HWLOC_LINUX_SYS */
 
-extern int hwloc_backend_xml_init(struct hwloc_topology *topology, const char *xmlpath, const char *xmlbuffer, int buflen);
-extern int hwloc_look_xml(struct hwloc_topology *topology);
-extern void hwloc_backend_xml_exit(struct hwloc_topology *topology);
-
 #ifdef HWLOC_SOLARIS_SYS
-extern void hwloc_look_solaris(struct hwloc_topology *topology);
-extern void hwloc_set_solaris_hooks(struct hwloc_topology *topology);
+extern void hwloc_set_solaris_hooks(struct hwloc_binding_hooks *binding_hooks, struct hwloc_topology_support *support);
 #endif /* HWLOC_SOLARIS_SYS */
 
 #ifdef HWLOC_AIX_SYS
-extern void hwloc_look_aix(struct hwloc_topology *topology);
-extern void hwloc_set_aix_hooks(struct hwloc_topology *topology);
+extern void hwloc_set_aix_hooks(struct hwloc_binding_hooks *binding_hooks, struct hwloc_topology_support *support);
 #endif /* HWLOC_AIX_SYS */
 
 #ifdef HWLOC_OSF_SYS
-extern void hwloc_look_osf(struct hwloc_topology *topology);
-extern void hwloc_set_osf_hooks(struct hwloc_topology *topology);
+extern void hwloc_set_osf_hooks(struct hwloc_binding_hooks *binding_hooks, struct hwloc_topology_support *support);
 #endif /* HWLOC_OSF_SYS */
 
 #ifdef HWLOC_WIN_SYS
-extern void hwloc_look_windows(struct hwloc_topology *topology);
-extern void hwloc_set_windows_hooks(struct hwloc_topology *topology);
+extern void hwloc_set_windows_hooks(struct hwloc_binding_hooks *binding_hooks, struct hwloc_topology_support *support);
 #endif /* HWLOC_WIN_SYS */
 
 #ifdef HWLOC_DARWIN_SYS
-extern void hwloc_look_darwin(struct hwloc_topology *topology);
-extern void hwloc_set_darwin_hooks(struct hwloc_topology *topology);
+extern void hwloc_set_darwin_hooks(struct hwloc_binding_hooks *binding_hooks, struct hwloc_topology_support *support);
 #endif /* HWLOC_DARWIN_SYS */
 
 #ifdef HWLOC_FREEBSD_SYS
-extern void hwloc_look_freebsd(struct hwloc_topology *topology);
-extern void hwloc_set_freebsd_hooks(struct hwloc_topology *topology);
+extern void hwloc_set_freebsd_hooks(struct hwloc_binding_hooks *binding_hooks, struct hwloc_topology_support *support);
 #endif /* HWLOC_FREEBSD_SYS */
 
 #ifdef HWLOC_HPUX_SYS
-extern void hwloc_look_hpux(struct hwloc_topology *topology);
-extern void hwloc_set_hpux_hooks(struct hwloc_topology *topology);
+extern void hwloc_set_hpux_hooks(struct hwloc_binding_hooks *binding_hooks, struct hwloc_topology_support *support);
 #endif /* HWLOC_HPUX_SYS */
 
-extern void hwloc_look_x86(struct hwloc_topology *topology, unsigned nbprocs);
-
-#ifdef HWLOC_HAVE_LIBPCI
-extern void hwloc_look_libpci(struct hwloc_topology *topology);
-#endif /* HWLOC_HAVE_LIBPCI */
-
-extern int hwloc_backend_synthetic_init(struct hwloc_topology *topology, const char *description);
-extern void hwloc_backend_synthetic_exit(struct hwloc_topology *topology);
-extern void hwloc_look_synthetic (struct hwloc_topology *topology);
-
 /*
  * Add an object to the topology.
  * It is sorted along the tree of other objects according to the inclusion of
@@ -256,16 +196,16 @@ extern void hwloc_look_synthetic (struct hwloc_topology *topology);
  *
  * In case of error, hwloc_report_os_error() is called.
  */
-extern void hwloc_insert_object_by_cpuset(struct hwloc_topology *topology, hwloc_obj_t obj);
+HWLOC_DECLSPEC void hwloc_insert_object_by_cpuset(struct hwloc_topology *topology, hwloc_obj_t obj);
 
 /* Error reporting */
 typedef void (*hwloc_report_error_t)(const char * msg, int line);
-extern void hwloc_report_os_error(const char * msg, int line);
-extern int hwloc_hide_errors(void);
+HWLOC_DECLSPEC void hwloc_report_os_error(const char * msg, int line);
+HWLOC_DECLSPEC int hwloc_hide_errors(void);
 /*
  * Add an object to the topology and specify which error callback to use
  */
-extern int hwloc__insert_object_by_cpuset(struct hwloc_topology *topology, hwloc_obj_t obj, hwloc_report_error_t report_error);
+HWLOC_DECLSPEC int hwloc__insert_object_by_cpuset(struct hwloc_topology *topology, hwloc_obj_t obj, hwloc_report_error_t report_error);
 
 /*
  * Insert an object somewhere in the topology.
@@ -278,7 +218,7 @@ extern int hwloc__insert_object_by_cpuset(struct hwloc_topology *topology, hwloc
  *
  * Remember to call topology_connect() afterwards to fix handy pointers.
  */
-extern void hwloc_insert_object_by_parent(struct hwloc_topology *topology, hwloc_obj_t parent, hwloc_obj_t obj);
+HWLOC_DECLSPEC void hwloc_insert_object_by_parent(struct hwloc_topology *topology, hwloc_obj_t parent, hwloc_obj_t obj);
 
 /* Insert uname-specific names/values in the object infos array */
 extern void hwloc_add_uname_info(struct hwloc_topology *topology);
@@ -306,10 +246,14 @@ hwloc_alloc_setup_object(hwloc_obj_type_t type, signed idx)
   /* do not allocate the cpuset here, let the caller do it */
   return obj;
 }
-
-extern void hwloc_free_unlinked_object(hwloc_obj_t obj);
 #endif
 
+/* Free obj and its attributes assuming it doesn't have any children/parent anymore */
+extern void hwloc_free_unlinked_object(hwloc_obj_t obj);
+
+/* Duplicate src and its children under newparent in newtopology */
+extern void hwloc__duplicate_objects(struct hwloc_topology *newtopology, struct hwloc_obj *newparent, struct hwloc_obj *src);
+
 /* This can be used for the alloc field to get allocated data that can be freed by free() */
 void *hwloc_alloc_heap(hwloc_topology_t topology, size_t len);
 
@@ -372,4 +316,27 @@ extern void hwloc_group_by_distances(struct hwloc_topology *topology);
 #define fabsf(f) fabs((double)(f))
 #endif
 
+#if HAVE_DECL__SC_PAGE_SIZE
+#define hwloc_getpagesize() sysconf(_SC_PAGE_SIZE)
+#elif HAVE_DECL__SC_PAGESIZE
+#define hwloc_getpagesize() sysconf(_SC_PAGESIZE)
+#elif defined HAVE_GETPAGESIZE
+#define hwloc_getpagesize() getpagesize()
+#else
+#undef hwloc_getpagesize
+#endif
+
+/* encode src buffer into target buffer.
+ * targsize must be at least 4*((srclength+2)/3)+1.
+ * target will be 0-terminated.
+ */
+extern int hwloc_encode_to_base64(const char *src, size_t srclength, char *target, size_t targsize);
+/* decode src buffer into target buffer.
+ * src is 0-terminated.
+ * targsize must be at least srclength*3/4+1 (srclength not including \0)
+ * but only srclength*3/4 characters will be meaningful
+ * (the next one may be partially written during decoding, but it should be ignored).
+ */
+extern int hwloc_decode_from_base64(char const *src, char *target, size_t targsize);
+
 #endif /* HWLOC_PRIVATE_H */
