@@ -1,6 +1,6 @@
 /*
  * Copyright © 2009 CNRS
- * Copyright © 2009-2010 INRIA.  All rights reserved.
+ * Copyright © 2009-2010 inria.  All rights reserved.
  * Copyright © 2009-2010 Université Bordeaux 1
  * Copyright © 2009-2011 Cisco Systems, Inc.  All rights reserved.
  * See COPYING in top-level directory.
@@ -29,6 +29,7 @@ int main(void)
   printf("ibv_get_device_list found %d devices\n", count);
 
   hwloc_topology_init(&topology);
+  hwloc_topology_set_flags(topology, HWLOC_TOPOLOGY_FLAG_IO_DEVICES);
   hwloc_topology_load(topology);
 
   for(i=0; i<count; i++) {
@@ -42,10 +43,22 @@ int main(void)
 	     i, ibv_get_device_name(dev));
     } else {
       char *cpuset_string = NULL;
+      hwloc_obj_t os;
+
       hwloc_bitmap_asprintf(&cpuset_string, set);
       printf("got cpuset %s for device %d (%s)\n",
 	     cpuset_string, i, ibv_get_device_name(dev));
       free(cpuset_string);
+
+      os = hwloc_ibv_get_device_osdev_by_name(topology, ibv_get_device_name(dev));
+      if (os) {
+	assert(os->type == HWLOC_OBJ_OS_DEVICE);
+	printf("found OS object subtype %u lindex %u name %s\n",
+	       (unsigned) os->attr->osdev.type, os->logical_index, os->name);
+	assert(os->attr->osdev.type == HWLOC_OBJ_OSDEV_OPENFABRICS);
+	if (strcmp(ibv_get_device_name(dev), os->name))
+	  assert(0);
+      }
     }
     hwloc_bitmap_free(set);
   }
