@@ -1,5 +1,5 @@
 /*
- * Copyright © 2009 INRIA.  All rights reserved.
+ * Copyright © 2009 inria.  All rights reserved.
  * Copyright © 2009 Université Bordeaux 1
  * See COPYING in top-level directory.
  */
@@ -10,4 +10,7 @@
 extern int sysctl(int *name, int name_len, void *oldp, size_t *oldlenp, void *newp, size_t newlen);
 extern int sysctlbyname(const char *name, void *oldp, size_t *oldlenp, void *newp, size_t newlen);
 
+#define CTL_HW 6
+#define HW_PHYSMEM 5
+
 #endif /* HWLOC_PORT_SYS_SYSCTL_H */
