@@ -1,7 +1,7 @@
 /*
  * Copyright © 2009 CNRS
- * Copyright © 2009-2011 INRIA.  All rights reserved.
- * Copyright © 2009-2011 Université Bordeaux 1
+ * Copyright © 2009-2012 Inria.  All rights reserved.
+ * Copyright © 2009-2012 Université Bordeaux 1
  * Copyright © 2009-2011 Cisco Systems, Inc.  All rights reserved.
  * See COPYING in top-level directory.
  */
@@ -15,13 +15,17 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#ifdef HAVE_DIRENT_H
 #include <dirent.h>
+#endif
 #include <fcntl.h>
 #include <assert.h>
 
+#ifdef LSTOPO_HAVE_GRAPHICS
 #ifdef HWLOC_HAVE_CAIRO
 #include <cairo.h>
 #endif
+#endif
 
 #ifdef HAVE_SETLOCALE
 #include <locale.h>
@@ -36,11 +40,11 @@ int show_cpuset = 0;
 int taskset = 0;
 unsigned int fontsize = 10;
 unsigned int gridsize = 10;
-unsigned int force_horiz = 0;
-unsigned int force_vert = 0;
+enum lstopo_orient_e force_orient[HWLOC_OBJ_TYPE_MAX];
 unsigned int legend = 1;
 unsigned int top = 0;
-hwloc_pid_t pid = (hwloc_pid_t) -1;
+int pid_number = -1;
+hwloc_pid_t pid;
 
 FILE *open_file(const char *filename, const char *mode)
 {
@@ -85,6 +89,7 @@ static hwloc_obj_t insert_task(hwloc_topology_t topology, hwloc_cpuset_t cpuset,
 
 static void add_process_objects(hwloc_topology_t topology)
 {
+#ifdef HAVE_DIRENT_H
   hwloc_obj_t root;
   hwloc_bitmap_t cpuset;
 #ifdef HWLOC_LINUX_SYS
@@ -110,17 +115,20 @@ static void add_process_objects(hwloc_topology_t topology)
 #endif /* HWLOC_LINUX_SYS */
 
   while ((dirent = readdir(dir))) {
-    long local_pid;
+    long local_pid_number;
+    hwloc_pid_t local_pid;
     char *end;
     char name[64];
     int proc_cpubind;
 
-    local_pid = strtol(dirent->d_name, &end, 10);
+    local_pid_number = strtol(dirent->d_name, &end, 10);
     if (*end)
       /* Not a number */
       continue;
 
-    snprintf(name, sizeof(name), "%ld", local_pid);
+    snprintf(name, sizeof(name), "%ld", local_pid_number);
+
+    local_pid = hwloc_pid_from_number(local_pid_number, 0);
 
     proc_cpubind = hwloc_get_proc_cpubind(topology, local_pid, cpuset, 0) != -1;
 
@@ -149,7 +157,7 @@ static void add_process_objects(hwloc_topology_t topology)
         cmd[n] = 0;
         if ((c = strchr(cmd, ' ')))
           *c = 0;
-        snprintf(name, sizeof(name), "%ld %s", local_pid, cmd);
+        snprintf(name, sizeof(name), "%ld %s", local_pid_number, cmd);
       }
     }
 
@@ -205,6 +213,7 @@ static void add_process_objects(hwloc_topology_t topology)
   hwloc_bitmap_free(task_cpuset);
 #endif /* HWLOC_LINUX_SYS */
   closedir(dir);
+#endif /* HAVE_DIRENT_H */
 }
 
 void usage(const char *name, FILE *where)
@@ -212,7 +221,7 @@ void usage(const char *name, FILE *where)
   fprintf (where, "Usage: %s [ options ] ... [ filename.format ]\n\n", name);
   fprintf (where, "See lstopo(1) for more details.\n\n");
   fprintf (where, "Supported output file formats: console, txt, fig"
-#ifdef HWLOC_HAVE_CAIRO
+#ifdef LSTOPO_HAVE_GRAPHICS
 #if CAIRO_HAS_PDF_SURFACE
 		  ", pdf"
 #endif /* CAIRO_HAS_PDF_SURFACE */
@@ -225,10 +234,8 @@ void usage(const char *name, FILE *where)
 #if CAIRO_HAS_SVG_SURFACE
 		  ", svg"
 #endif /* CAIRO_HAS_SVG_SURFACE */
-#endif /* HWLOC_HAVE_CAIRO */
-#ifdef HWLOC_HAVE_XML
-		  ", xml"
-#endif /* HWLOC_HAVE_XML */
+#endif /* LSTOPO_HAVE_GRAPHICS */
+		  ", xml, synthetic"
 		  "\n");
   fprintf (where, "\nFormatting options:\n");
   fprintf (where, "  -l --logical          Display hwloc logical object indexes\n");
@@ -250,10 +257,16 @@ void usage(const char *name, FILE *where)
   fprintf (where, "  --no-caches           Do not show caches\n");
   fprintf (where, "  --no-useless-caches   Do not show caches which do not have a hierarchical\n"
                   "                        impact\n");
+  fprintf (where, "  --no-icaches          Do not show instruction caches\n");
   fprintf (where, "  --merge               Do not show levels that do not have a hierarchical\n"
                   "                        impact\n");
   fprintf (where, "  --restrict <cpuset>   Restrict the topology to processors listed in <cpuset>\n");
   fprintf (where, "  --restrict binding    Restrict the topology to the current process binding\n");
+#ifdef HWLOC_HAVE_LIBPCI
+  fprintf (where, "  --no-io               Do not show any I/O device or bridge\n");
+  fprintf (where, "  --no-bridges          Do not any I/O bridge except hostbridges\n");
+  fprintf (where, "  --whole-io            Show all I/O devices and bridges\n");
+#endif
   fprintf (where, "Input options:\n");
   hwloc_utils_input_format_usage(where, 6);
   fprintf (where, "  --thissystem          Assume that the input topology provides the topology\n"
@@ -263,8 +276,8 @@ void usage(const char *name, FILE *where)
   fprintf (where, "Graphical output options:\n");
   fprintf (where, "  --fontsize 10         Set size of text font\n");
   fprintf (where, "  --gridsize 10         Set size of margin between elements\n");
-  fprintf (where, "  --horiz               Horizontal graphical layout instead of nearly 4/3 ratio\n");
-  fprintf (where, "  --vert                Vertical graphical layout instead of nearly 4/3 ratio\n");
+  fprintf (where, "  --horiz[=<type,...>]  Horizontal graphical layout instead of nearly 4/3 ratio\n");
+  fprintf (where, "  --vert[=<type,...>]   Vertical graphical layout instead of nearly 4/3 ratio\n");
   fprintf (where, "  --no-legend           Remove the text legend at the bottom\n");
   fprintf (where, "Miscellaneous options:\n");
   fprintf (where, "  --ps --top            Display processes within the hierarchy\n");
@@ -274,6 +287,7 @@ void usage(const char *name, FILE *where)
 enum output_format {
   LSTOPO_OUTPUT_DEFAULT,
   LSTOPO_OUTPUT_CONSOLE,
+  LSTOPO_OUTPUT_SYNTHETIC,
   LSTOPO_OUTPUT_TEXT,
   LSTOPO_OUTPUT_FIG,
   LSTOPO_OUTPUT_PNG,
@@ -286,10 +300,12 @@ enum output_format {
 static enum output_format
 parse_output_format(const char *name, char *callname)
 {
-  if (!strncasecmp(name, "default", 3))
+  if (!hwloc_strncasecmp(name, "default", 3))
     return LSTOPO_OUTPUT_DEFAULT;
-  else if (!strncasecmp(name, "console", 3))
+  else if (!hwloc_strncasecmp(name, "console", 3))
     return LSTOPO_OUTPUT_CONSOLE;
+  else if (!strcasecmp(name, "synthetic"))
+    return LSTOPO_OUTPUT_SYNTHETIC;
   else if (!strcasecmp(name, "txt"))
     return LSTOPO_OUTPUT_TEXT;
   else if (!strcasecmp(name, "fig"))
@@ -319,7 +335,7 @@ main (int argc, char *argv[])
   int verbose_mode = LSTOPO_VERBOSE_MODE_DEFAULT;
   hwloc_topology_t topology;
   const char *filename = NULL;
-  unsigned long flags = 0;
+  unsigned long flags = HWLOC_TOPOLOGY_FLAG_IO_DEVICES | HWLOC_TOPOLOGY_FLAG_IO_BRIDGES | HWLOC_TOPOLOGY_FLAG_ICACHES;
   int merge = 0;
   int ignorecache = 0;
   char * callname;
@@ -328,6 +344,17 @@ main (int argc, char *argv[])
   enum output_format output_format = LSTOPO_OUTPUT_DEFAULT;
   char *restrictstring = NULL;
   int opt;
+  unsigned i;
+
+  for(i=0; i<HWLOC_OBJ_TYPE_MAX; i++)
+    force_orient[i] = LSTOPO_ORIENT_NONE;
+  force_orient[HWLOC_OBJ_PU] = LSTOPO_ORIENT_HORIZ;
+  force_orient[HWLOC_OBJ_CACHE] = LSTOPO_ORIENT_HORIZ;
+  force_orient[HWLOC_OBJ_NODE] = LSTOPO_ORIENT_HORIZ;
+
+  /* enable verbose backends */
+  putenv("HWLOC_XML_VERBOSE=1");
+  putenv("HWLOC_SYNTHETIC_VERBOSE=1");
 
 #ifdef HAVE_SETLOCALE
   setlocale(LC_ALL, "");
@@ -338,120 +365,153 @@ main (int argc, char *argv[])
     callname = argv[0];
   else
     callname++;
+  /* skip argv[0], handle options */
+  argc--;
+  argv++;
 
   err = hwloc_topology_init (&topology);
   if (err)
     return EXIT_FAILURE;
 
-  while (argc >= 2)
+  while (argc >= 1)
     {
       opt = 0;
-      if (!strcmp (argv[1], "-v") || !strcmp (argv[1], "--verbose")) {
+      if (!strcmp (argv[0], "-v") || !strcmp (argv[0], "--verbose")) {
 	verbose_mode++;
-      } else if (!strcmp (argv[1], "-s") || !strcmp (argv[1], "--silent")) {
+      } else if (!strcmp (argv[0], "-s") || !strcmp (argv[0], "--silent")) {
 	verbose_mode--;
-      } else if (!strcmp (argv[1], "-h") || !strcmp (argv[1], "--help")) {
+      } else if (!strcmp (argv[0], "-h") || !strcmp (argv[0], "--help")) {
 	usage(callname, stdout);
         exit(EXIT_SUCCESS);
-      } else if (!strcmp (argv[1], "-l") || !strcmp (argv[1], "--logical"))
+      } else if (!strcmp (argv[0], "-l") || !strcmp (argv[0], "--logical"))
 	logical = 1;
-      else if (!strcmp (argv[1], "-p") || !strcmp (argv[1], "--physical"))
+      else if (!strcmp (argv[0], "-p") || !strcmp (argv[0], "--physical"))
 	logical = 0;
-      else if (!strcmp (argv[1], "-c") || !strcmp (argv[1], "--cpuset"))
+      else if (!strcmp (argv[0], "-c") || !strcmp (argv[0], "--cpuset"))
 	show_cpuset = 1;
-      else if (!strcmp (argv[1], "-C") || !strcmp (argv[1], "--cpuset-only"))
+      else if (!strcmp (argv[0], "-C") || !strcmp (argv[0], "--cpuset-only"))
 	show_cpuset = 2;
-      else if (!strcmp (argv[1], "--taskset")) {
+      else if (!strcmp (argv[0], "--taskset")) {
 	taskset = 1;
 	if (!show_cpuset)
 	  show_cpuset = 1;
-      } else if (!strcmp (argv[1], "--only")) {
-	if (argc <= 2) {
+      } else if (!strcmp (argv[0], "--only")) {
+	if (argc < 2) {
 	  usage (callname, stderr);
 	  exit(EXIT_FAILURE);
 	}
-        show_only = hwloc_obj_type_of_string(argv[2]);
+        show_only = hwloc_obj_type_of_string(argv[1]);
 	opt = 1;
       }
-      else if (!strcmp (argv[1], "--ignore")) {
-	if (argc <= 2) {
+      else if (!strcmp (argv[0], "--ignore")) {
+	if (argc < 2) {
 	  usage (callname, stderr);
 	  exit(EXIT_FAILURE);
 	}
-        hwloc_topology_ignore_type(topology, hwloc_obj_type_of_string(argv[2]));
+        hwloc_topology_ignore_type(topology, hwloc_obj_type_of_string(argv[1]));
 	opt = 1;
       }
-      else if (!strcmp (argv[1], "--no-caches"))
+      else if (!strcmp (argv[0], "--no-caches"))
 	ignorecache = 2;
-      else if (!strcmp (argv[1], "--no-useless-caches"))
+      else if (!strcmp (argv[0], "--no-useless-caches"))
 	ignorecache = 1;
-      else if (!strcmp (argv[1], "--whole-system"))
+      else if (!strcmp (argv[0], "--no-icaches"))
+	flags &= ~HWLOC_TOPOLOGY_FLAG_ICACHES;
+      else if (!strcmp (argv[0], "--whole-system"))
 	flags |= HWLOC_TOPOLOGY_FLAG_WHOLE_SYSTEM;
-      else if (!strcmp (argv[1], "--merge"))
+      else if (!strcmp (argv[0], "--no-io"))
+	flags &= ~(HWLOC_TOPOLOGY_FLAG_IO_DEVICES | HWLOC_TOPOLOGY_FLAG_IO_BRIDGES);
+      else if (!strcmp (argv[0], "--no-bridges"))
+	flags &= ~(HWLOC_TOPOLOGY_FLAG_IO_BRIDGES);
+      else if (!strcmp (argv[0], "--whole-io"))
+	flags |= HWLOC_TOPOLOGY_FLAG_WHOLE_IO;
+      else if (!strcmp (argv[0], "--merge"))
 	merge = 1;
-      else if (!strcmp (argv[1], "--thissystem"))
+      else if (!strcmp (argv[0], "--thissystem"))
 	flags |= HWLOC_TOPOLOGY_FLAG_IS_THISSYSTEM;
-      else if (!strcmp (argv[1], "--restrict")) {
-	if (argc <= 2) {
+      else if (!strcmp (argv[0], "--restrict")) {
+	if (argc < 2) {
 	  usage (callname, stderr);
 	  exit(EXIT_FAILURE);
 	}
-	restrictstring = strdup(argv[2]);
-	opt = 1;
-      } else if (!strcmp (argv[1], "--horiz"))
-        force_horiz = 1;
-      else if (!strcmp (argv[1], "--vert"))
-        force_vert = 1;
-      else if (!strcmp (argv[1], "--fontsize")) {
-	if (argc <= 2) {
-	  usage (callname, stderr);
-	  exit(EXIT_FAILURE);
-	}
-	fontsize = atoi(argv[2]);
+	restrictstring = strdup(argv[1]);
 	opt = 1;
       }
-      else if (!strcmp (argv[1], "--gridsize")) {
-	if (argc <= 2) {
+
+      else if (!strcmp (argv[0], "--horiz"))
+	for(i=0; i<HWLOC_OBJ_TYPE_MAX; i++)
+	  force_orient[i] = LSTOPO_ORIENT_HORIZ;
+      else if (!strcmp (argv[0], "--vert"))
+	for(i=0; i<HWLOC_OBJ_TYPE_MAX; i++)
+	  force_orient[i] = LSTOPO_ORIENT_VERT;
+      else if (!strncmp (argv[0], "--horiz=", 8)
+	       || !strncmp (argv[0], "--vert=", 7)) {
+	enum lstopo_orient_e orient = (argv[0][2] == 'h') ? LSTOPO_ORIENT_HORIZ : LSTOPO_ORIENT_VERT;
+	char *tmp = argv[0] + ((argv[0][2] == 'h') ? 8 : 7);
+	while (tmp) {
+	  char *end = strchr(tmp, ',');
+	  hwloc_obj_type_t type;
+	  if (end)
+	    *end = '\0';
+	  type = hwloc_obj_type_of_string(tmp);
+	  if (type != (hwloc_obj_type_t) -1)
+	    force_orient[type] = orient;
+	  if (!end)
+	    break;
+	  tmp = end+1;
+        }
+      }
+
+      else if (!strcmp (argv[0], "--fontsize")) {
+	if (argc < 2) {
 	  usage (callname, stderr);
 	  exit(EXIT_FAILURE);
 	}
-	gridsize = atoi(argv[2]);
+	fontsize = atoi(argv[1]);
 	opt = 1;
       }
-      else if (!strcmp (argv[1], "--no-legend")) {
+      else if (!strcmp (argv[0], "--gridsize")) {
+	if (argc < 2) {
+	  usage (callname, stderr);
+	  exit(EXIT_FAILURE);
+	}
+	gridsize = atoi(argv[1]);
+	opt = 1;
+      }
+      else if (!strcmp (argv[0], "--no-legend")) {
 	legend = 0;
       }
 
-      else if (hwloc_utils_lookup_input_option(argv+1, argc-1, &opt,
+      else if (hwloc_utils_lookup_input_option(argv, argc, &opt,
 					       &input, &input_format,
 					       callname)) {
 	/* nothing to do anymore */
 
-      } else if (!strcmp (argv[1], "--pid")) {
-	if (argc <= 2) {
+      } else if (!strcmp (argv[0], "--pid")) {
+	if (argc < 2) {
 	  usage (callname, stderr);
 	  exit(EXIT_FAILURE);
 	}
-	pid = atoi(argv[2]); opt = 1;
-      } else if (!strcmp (argv[1], "--ps") || !strcmp (argv[1], "--top"))
+	pid_number = atoi(argv[1]); opt = 1;
+      } else if (!strcmp (argv[0], "--ps") || !strcmp (argv[0], "--top"))
         top = 1;
-      else if (!strcmp (argv[1], "--version")) {
+      else if (!strcmp (argv[0], "--version")) {
           printf("%s %s\n", callname, VERSION);
           exit(EXIT_SUCCESS);
-      } else if (!strcmp (argv[1], "--output-format") || !strcmp (argv[1], "--of")) {
-	if (argc <= 2) {
+      } else if (!strcmp (argv[0], "--output-format") || !strcmp (argv[0], "--of")) {
+	if (argc < 2) {
 	  usage (callname, stderr);
 	  exit(EXIT_FAILURE);
 	}
-        output_format = parse_output_format(argv[2], callname);
+        output_format = parse_output_format(argv[1], callname);
         opt = 1;
       } else {
 	if (filename) {
-	  fprintf (stderr, "Unrecognized option: %s\n", argv[1]);
+	  fprintf (stderr, "Unrecognized option: %s\n", argv[0]);
 	  usage (callname, stderr);
 	  exit(EXIT_FAILURE);
 	} else
-	  filename = argv[1];
+	  filename = argv[0];
       }
       argc -= opt+1;
       argv += opt+1;
@@ -470,10 +530,14 @@ main (int argc, char *argv[])
   if (merge)
     hwloc_topology_ignore_all_keep_structure(topology);
 
-  if (input)
-    hwloc_utils_enable_input_format(topology, input, input_format, verbose_mode > 1, callname);
+  if (input) {
+    err = hwloc_utils_enable_input_format(topology, input, input_format, verbose_mode > 1, callname);
+    if (err)
+      return err;
+  }
 
-  if (pid != (hwloc_pid_t) -1 && pid != 0) {
+  if (pid_number != -1 && pid_number != 0) {
+    pid = hwloc_pid_from_number(pid_number, 0);
     if (hwloc_topology_set_pid(topology, pid)) {
       perror("Setting target pid");
       return EXIT_FAILURE;
@@ -490,7 +554,7 @@ main (int argc, char *argv[])
   if (restrictstring) {
     hwloc_bitmap_t restrictset = hwloc_bitmap_alloc();
     if (!strcmp (restrictstring, "binding")) {
-      if (pid != (hwloc_pid_t) -1 && pid != 0)
+      if (pid_number != -1 && pid_number != 0)
 	hwloc_get_proc_cpubind(topology, pid, restrictset, HWLOC_CPUBIND_PROCESS);
       else
 	hwloc_get_cpubind(topology, restrictset, HWLOC_CPUBIND_PROCESS);
@@ -541,7 +605,7 @@ main (int argc, char *argv[])
 
   switch (output_format) {
     case LSTOPO_OUTPUT_DEFAULT:
-#ifdef HWLOC_HAVE_CAIRO
+#ifdef LSTOPO_HAVE_GRAPHICS
 #if CAIRO_HAS_XLIB_SURFACE && defined HWLOC_HAVE_X11
       if (getenv("DISPLAY")) {
         if (logical == -1)
@@ -549,14 +613,15 @@ main (int argc, char *argv[])
         output_x11(topology, NULL, logical, legend, verbose_mode);
       } else
 #endif /* CAIRO_HAS_XLIB_SURFACE */
-#endif /* HWLOC_HAVE_CAIRO */
 #ifdef HWLOC_WIN_SYS
       {
         if (logical == -1)
           logical = 0;
         output_windows(topology, NULL, logical, legend, verbose_mode);
       }
-#else
+#endif
+#endif /* !LSTOPO_HAVE_GRAPHICS */
+#if !defined HWLOC_WIN_SYS || !defined LSTOPO_HAVE_GRAPHICS
       {
         if (logical == -1)
           logical = 1;
@@ -568,13 +633,16 @@ main (int argc, char *argv[])
     case LSTOPO_OUTPUT_CONSOLE:
       output_console(topology, filename, logical, legend, verbose_mode);
       break;
+    case LSTOPO_OUTPUT_SYNTHETIC:
+      output_synthetic(topology, filename, logical, legend, verbose_mode);
+      break;
     case LSTOPO_OUTPUT_TEXT:
       output_text(topology, filename, logical, legend, verbose_mode);
       break;
     case LSTOPO_OUTPUT_FIG:
       output_fig(topology, filename, logical, legend, verbose_mode);
       break;
-#ifdef HWLOC_HAVE_CAIRO
+#ifdef LSTOPO_HAVE_GRAPHICS
 # if CAIRO_HAS_PNG_FUNCTIONS
     case LSTOPO_OUTPUT_PNG:
       output_png(topology, filename, logical, legend, verbose_mode);
@@ -595,12 +663,10 @@ main (int argc, char *argv[])
       output_svg(topology, filename, logical, legend, verbose_mode);
       break;
 #endif /* CAIRO_HAS_SVG_SURFACE */
-#endif /* HWLOC_HAVE_CAIRO */
-#ifdef HWLOC_HAVE_XML
+#endif /* LSTOPO_HAVE_GRAPHICS */
     case LSTOPO_OUTPUT_XML:
       output_xml(topology, filename, logical, legend, verbose_mode);
       break;
-#endif
     default:
       fprintf(stderr, "file format not supported\n");
       usage(callname, stderr);
