@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -64,11 +64,11 @@ char * get_sock_error_string(int error)
         return str;
     }
 
-    str[0] = '\0';
+    /* str[0] = '\0'; */
     /*
     SMPDR_Err_get_string(error, str, 1024, SMPDU_Sock_get_error_class_string);
     */
-    smpd_translate_win_error(error, str, 1024, "(error =", error, ") ");
+    /* smpd_translate_win_error(error, str, 1024, "(error =", error, ") "); */
     /*
     SMPDR_Err_get_string_ext(error, str, 1024, SMPDU_Sock_get_error_class_string);
     if (SMPDR_Err_print_stack_flag)
@@ -82,7 +82,7 @@ char * get_sock_error_string(int error)
     }
     */
 
-    return str;
+    /* return str; */
 }
 
 char * smpd_get_context_str(smpd_context_t *context)
@@ -548,6 +548,31 @@ void smpd_trim_logfile_old()
 }
 #endif
 
+#ifdef HAVE_WINDOWS_H
+int smpd_tprintf_templ(smpd_printf_fp_t fp, TCHAR *str, ...){
+    char *str_mb = NULL;
+    int len = 0;
+    int result = 0;
+    va_list args;
+
+    len = _tcslen(str) * sizeof(TCHAR) + 1;
+    str_mb = (char *)MPIU_Malloc(len);
+    if(str_mb == NULL){
+        smpd_err_printf("Unable to allocate memory for temp buffer\n");
+        return 0;
+    }
+    SMPDU_TCSTOMBS(str_mb, str, len);
+
+    va_start(args, str);
+    fp(str_mb, args);
+    va_end(args);
+
+    MPIU_Free(str_mb);
+
+    return result;
+}
+#endif 
+
 int smpd_err_printf(char *str, ...)
 {
     va_list list;
