@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -251,7 +251,7 @@ static BOOL smpd_setup_service_restart( SC_HANDLE schService )
 	return FALSE;
 
     /* Add a description string */
-    ds.lpDescription = "Process manager service for MPICH2 applications";
+    ds.lpDescription = "Process manager service for MPICH applications";
     ChangeServiceConfig2_fn(schService, SERVICE_CONFIG_DESCRIPTION, &ds);
 
     /* The actions in this array are performed in order each time the service fails 
@@ -308,19 +308,32 @@ BOOL Is_DomainController()
 
   COMMENTS:
 */
+
+/* FIXME: Remove hardcoded values -- eg: Length of error Mesg, 256*/
+
+#define SMPD_MAX_FILENAME_DECORATION (2 * sizeof(TCHAR))
+#define SMPD_MAX_FILENAME_QUOTED (SMPD_MAX_FILENAME + SMPD_MAX_FILENAME_DECORATION)
 void smpd_install_service(SMPD_BOOL interact, SMPD_BOOL bSetupRestart, SMPD_BOOL bSetupScp)
 {
     SC_HANDLE   schService;
     SC_HANDLE   schSCManager;
     TCHAR szErr[256];
-    TCHAR szPath[1024];
+    TCHAR szPathQuoted[SMPD_MAX_FILENAME_QUOTED];
+    LPTSTR pszPathQuoted;
     
-    if ( GetModuleFileName( NULL, szPath, 1024 ) == 0 )
+    pszPathQuoted = szPathQuoted;
+    /* The smpd module file name has to be quoted before passing to CreateService() --- refer MSDN doc for 
+     * CreateService() 
+     */
+    _stprintf(pszPathQuoted, TEXT("\""));
+    if ( GetModuleFileName( NULL, pszPathQuoted+1, SMPD_MAX_FILENAME ) == 0 )
     {
         _tprintf(TEXT("Unable to install %s.\n%s\n"), TEXT(SMPD_SERVICE_DISPLAY_NAME), smpd_get_last_error_text(szErr, 256));
 	fflush(stdout);
         return;
     }
+    
+    _stprintf(pszPathQuoted + _tcslen(pszPathQuoted), TEXT("\""));
 
     schSCManager = OpenSCManager(NULL, NULL, SC_MANAGER_ALL_ACCESS);
     if ( schSCManager )
@@ -337,7 +350,7 @@ void smpd_install_service(SMPD_BOOL interact, SMPD_BOOL bSetupRestart, SMPD_BOOL
 	    SERVICE_AUTO_START,
             /*SERVICE_ERROR_NORMAL,*/       /* error control type */
 	    SERVICE_ERROR_IGNORE,
-            szPath,                     /* service's binary */
+            szPathQuoted,                /* service's binary */
             NULL,                       /* no load ordering group */
             NULL,                       /* no tag identifier */
             TEXT(""),                   /* dependencies */
@@ -681,9 +694,9 @@ void smpd_bomb_thread()
 */    
 void smpd_service_stop()
 {
-    MPIDU_Sock_set_t set;
-    MPIDU_Sock_t sock;
-    MPIDU_Sock_event_t event;
+    SMPDU_Sock_set_t set;
+    SMPDU_Sock_t sock;
+    SMPDU_Sock_event_t event;
     char host[SMPD_MAX_HOST_LENGTH];
     int iter;
     DWORD dwThreadID;
@@ -700,17 +713,17 @@ void smpd_service_stop()
     /* stop the main thread */
     smpd_process.service_stop = SMPD_TRUE;
     smpd_get_hostname(host, SMPD_MAX_HOST_LENGTH);
-    result = MPIDU_Sock_create_set(&set);
-    if (result != MPI_SUCCESS)
+    result = SMPDU_Sock_create_set(&set);
+    if (result != SMPD_SUCCESS)
     {
-	smpd_err_printf("MPIDU_Sock_create_set failed,\nsock error: %s\n", get_sock_error_string(result));
+	smpd_err_printf("SMPDU_Sock_create_set failed,\nsock error: %s\n", get_sock_error_string(result));
 	SetEvent(smpd_process.hBombDiffuseEvent);
 	WaitForSingleObject(smpd_process.hBombThread, (DWORD)3000);
 	CloseHandle(smpd_process.hBombThread);
 	ExitProcess((UINT)-1);
     }
-    result = MPIDU_Sock_post_connect(set, NULL, host, smpd_process.port, &sock);
-    if (result != MPI_SUCCESS)
+    result = SMPDU_Sock_post_connect(set, NULL, host, smpd_process.port, &sock);
+    if (result != SMPD_SUCCESS)
     {
 	smpd_err_printf("Unable to connect to '%s:%d',\nsock error: %s\n",
 	    smpd_process.host_list->host, smpd_process.port, get_sock_error_string(result));
@@ -719,8 +732,8 @@ void smpd_service_stop()
 	CloseHandle(smpd_process.hBombThread);
 	ExitProcess((UINT)-1);
     }
-    result = MPIDU_Sock_wait(set, MPIDU_SOCK_INFINITE_TIME, &event);
-    if (result != MPI_SUCCESS)
+    result = SMPDU_Sock_wait(set, SMPDU_SOCK_INFINITE_TIME, &event);
+    if (result != SMPD_SUCCESS)
     {
 	smpd_err_printf("Unable to connect to '%s:%d',\nsock error: %s\n",
 	    smpd_process.host_list->host, smpd_process.port, get_sock_error_string(result));
