@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *
  *  (C) 2003 by Argonne National Laboratory.
@@ -8,7 +8,9 @@
 #include <stdio.h>
 #include "mpitest.h"
 
+/*
 static char MTEST_Descrip[] = "Test of broadcast with various roots and datatypes";
+*/
 
 int main( int argc, char *argv[] )
 {
@@ -35,9 +37,9 @@ int main( int argc, char *argv[] )
 	   change the error handler to errors return */
 	MPI_Errhandler_set( comm, MPI_ERRORS_RETURN );
 
-	/* This must be very large to ensure that we reach the long message
-	   algorithms */
-	for (count = 1; count < 66000; count = count * 4) {
+	/* The max value of count must be very large to ensure that we 
+	   reach the long message algorithms */
+	for (count = 1; count < 280000; count = count * 4) {
 	    while (MTestGetDatatypes( &sendtype, &recvtype, count )) {
 		for (root=0; root<size; root++) {
 		    if (rank == root) {
