@@ -8,10 +8,16 @@
 ! Test user-defined operations.  This tests a simple commutative operation
 !
       subroutine uop( cin, cout, count, datatype )
+      use mpi
       integer cin(*), cout(*)
       integer count, datatype
       integer i
       
+      if (datatype .ne. MPI_INTEGER) then
+         print *, 'Invalid datatype (',datatype,') passed to user_op()'
+         return
+      endif
+
       do i=1, count
          cout(i) = cin(i) + cout(i)
       enddo
