@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2006 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -25,7 +25,9 @@ int main(int argc, char* argv[])
   
   MPI_Win_wait(win);
 
+  MPI_Group_free( &group );
   MPI_Win_free(&win); 
+
   MTest_Finalize(errs);
   MPI_Finalize();
   return 0;
