@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -24,6 +24,7 @@
 #include <stdint.h>
 #include <mpi.h>
 #include "mpitest.h"
+#include "squelch.h"
 
 #define XDIM 1024
 #define YDIM 1024
@@ -31,19 +32,6 @@
 #define SUB_YDIM 1024
 #define ITERATIONS 10
 
-static const int SQ_LIMIT = 10;
-static       int SQ_COUNT = 0;
-
-#define SQUELCH(X)                      \
-  do {                                  \
-    if (SQ_COUNT < SQ_LIMIT) {          \
-      SQ_COUNT++;                       \
-      X                                 \
-    }                                   \
-  } while (0)
-
-static int verbose = 0;
-
 int main(int argc, char **argv) {
     int i, j, rank, nranks, peer, bufsize, errors;
     double  *win_buf, *src_buf, *dst_buf;
@@ -61,9 +49,6 @@ int main(int argc, char **argv) {
     MPI_Alloc_mem(bufsize, MPI_INFO_NULL, &src_buf);
     MPI_Alloc_mem(bufsize, MPI_INFO_NULL, &dst_buf);
 
-    if (rank == 0)
-        if (verbose) printf("MPI RMA Strided Put Test:\n");
-
     for (i = 0; i < XDIM*YDIM; i++) {
         *(win_buf  + i) = 1.0 + rank;
         *(src_buf + i) = 1.0 + rank;
@@ -86,9 +71,6 @@ int main(int argc, char **argv) {
 
       MPI_Get_address(base_ptr, &base_int);
 
-      if (rank == 0)
-        if (verbose) printf(" + iteration %d\n", i);
-
       for (j = 0; j < SUB_YDIM; j++) {
         MPI_Get_address(&src_buf[j*XDIM], &idx_loc[j]);
         idx_loc[j] = idx_loc[j] - base_int;
