@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -20,6 +20,7 @@
 #include <math.h>
 #include <mpi.h>
 #include "mpitest.h"
+#include "squelch.h"
 
 #define XDIM 16
 #define YDIM 16
@@ -27,21 +28,6 @@
 #define SUB_YDIM 8
 #define ITERATIONS 1
 
-static const int SQ_LIMIT = 10;
-static       int SQ_COUNT = 0;
-
-#define SQUELCH(X)                      \
-  do {                                  \
-    if (SQ_COUNT < SQ_LIMIT) {          \
-      SQ_COUNT++;                       \
-      X                                 \
-    }                                   \
-  } while (0)
-
-/*
-static int verbose = 0;
-*/
-
 int main(int argc, char **argv) {
     int itr, i, j, rank, nranks, peer, bufsize, errors;
     double *win_buf, *src_buf;
@@ -56,12 +42,6 @@ int main(int argc, char **argv) {
     MPI_Alloc_mem(bufsize, MPI_INFO_NULL, &win_buf);
     MPI_Alloc_mem(bufsize, MPI_INFO_NULL, &src_buf);
 
-    /*
-    Commment this out to avoid gcc --enable-stricttest warning.
-    if (rank == 0)
-        if (verbose) ("MPI RMA Strided Accumulate Test:\n");
-    */
-
     for (i = 0; i < XDIM*YDIM; i++) {
         *(win_buf + i) = -1.0;
         *(src_buf + i) = 1.0 + rank;
