@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -20,6 +20,7 @@
 #include <math.h>
 #include <mpi.h>
 #include "mpitest.h"
+#include "squelch.h"
 
 #define XDIM 8
 #define YDIM 1024
@@ -27,19 +28,6 @@
 #define SUB_YDIM 255
 #define ITERATIONS 10
 
-static const int SQ_LIMIT = 10;
-static       int SQ_COUNT = 0;
-
-#define SQUELCH(X)                      \
-  do {                                  \
-    if (SQ_COUNT < SQ_LIMIT) {          \
-      SQ_COUNT++;                       \
-      X                                 \
-    }                                   \
-  } while (0)
-
-static int verbose = 0;
-
 int main(int argc, char **argv) {
     int i, j, rank, nranks, peer, bufsize, errors;
     double *win_buf, *src_buf, *dst_buf;
@@ -55,9 +43,6 @@ int main(int argc, char **argv) {
     MPI_Alloc_mem(bufsize, MPI_INFO_NULL, &src_buf);
     MPI_Alloc_mem(bufsize, MPI_INFO_NULL, &dst_buf);
 
-    if (rank == 0)
-        if (verbose) printf("MPI RMA Strided Accumulate Test:\n");
-
     for (i = 0; i < XDIM*YDIM; i++) {
         *(win_buf + i) = -1.0;
         *(src_buf + i) =  1.0 + rank;
@@ -70,13 +55,11 @@ int main(int argc, char **argv) {
     /* Perform ITERATIONS strided accumulate operations */
 
     for (i = 0; i < ITERATIONS; i++) {
-      MPI_Aint idx_loc[SUB_YDIM];
       int idx_rem[SUB_YDIM];
       int blk_len[SUB_YDIM];
       MPI_Datatype src_type, dst_type;
 
       for (j = 0; j < SUB_YDIM; j++) {
-        MPI_Get_address(&src_buf[j*XDIM], &idx_loc[j]);
         idx_rem[j] = j*XDIM;
         blk_len[j] = SUB_XDIM;
       }
