@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
  *  (C) 2001 by Argonne National Laboratory.
  *      See COPYRIGHT in top-level directory.
@@ -7,6 +7,7 @@
 #include "stdio.h"
 #include "stdlib.h"
 #include "mpitest.h"
+#include "squelch.h"
 
 /* tests passive target RMA on 2 processes. tests the lock-single_op-unlock 
    optimization. */
@@ -66,7 +67,7 @@ int main(int argc, char *argv[])
 
             for (i=0; i<SIZE1; i++)
                 if (B[i] != (-4)*(i+SIZE1)) {
-                    printf("Get Error: B[%d] is %d, should be %d\n", i, B[i], (-4)*(i+SIZE1));
+                    SQUELCH( printf("Get Error: B[%d] is %d, should be %d\n", i, B[i], (-4)*(i+SIZE1)); );
                     errs++;
                 }
         }
@@ -78,7 +79,7 @@ int main(int argc, char *argv[])
 
             for (i=0; i<SIZE1; i++) {
                 if (B[i] != i) {
-                    printf("Put Error: B[%d] is %d, should be %d\n", i, B[i], i);
+                    SQUELCH( printf("Put Error: B[%d] is %d, should be %d\n", i, B[i], i); );
                     errs++;
                 }
             }
